@@ -36,6 +36,7 @@ import com.google.common.collect.Lists;
 
 import java.io.IOException;
 import java.math.BigDecimal;
+import java.nio.ByteBuffer;
 import java.util.Arrays;
 import java.util.List;
 import java.util.Map;
@@ -307,6 +308,13 @@ public class AssertExecutor {
             return checkDecimalType(value, fieldType);
         }
 
+        if (fieldType.getSqlType() == SqlType.FLOAT_VECTOR
+                || fieldType.getSqlType() == SqlType.FLOAT16_VECTOR
+                || fieldType.getSqlType() == SqlType.BFLOAT16_VECTOR
+                || fieldType.getSqlType() == SqlType.BINARY_VECTOR) {
+            return value instanceof ByteBuffer;
+        }
+
         return value.getClass().equals(fieldType.getTypeClass());
     }
 
