@@ -23,15 +23,19 @@ import org.apache.seatunnel.common.utils.SeaTunnelException;
 import org.apache.seatunnel.connectors.cdc.base.source.offset.Offset;
 import org.apache.seatunnel.connectors.cdc.base.utils.SourceRecordUtils;
 import org.apache.seatunnel.connectors.seatunnel.cdc.postgres.source.offset.LsnOffset;
+import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.JdbcDialect;
+import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.psql.PostgresDialect;
 
 import org.apache.kafka.connect.source.SourceRecord;
 
+import io.debezium.connector.postgresql.SourceInfo;
 import io.debezium.connector.postgresql.connection.Lsn;
 import io.debezium.connector.postgresql.connection.PostgresConnection;
 import io.debezium.jdbc.JdbcConnection;
 import io.debezium.relational.Column;
 import io.debezium.relational.Table;
 import io.debezium.relational.TableId;
+import io.debezium.time.Conversions;
 import lombok.extern.slf4j.Slf4j;
 
 import java.sql.Connection;
@@ -39,6 +43,7 @@ import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.sql.Statement;
+import java.time.Instant;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashMap;
@@ -51,15 +56,20 @@ import java.util.Optional;
 @Slf4j
 public class PostgresUtils {
     private static final int DEFAULT_FETCH_SIZE = 1024;
+    private static final JdbcDialect JDBC_DIALECT = new PostgresDialect();
 
     private PostgresUtils() {}
 
-    public static Object[] queryMinMax(JdbcConnection jdbc, TableId tableId, String columnName)
+    public static Object[] queryMinMax(
+            JdbcConnection jdbc, TableId tableId, String columnName, Column column)
             throws SQLException {
+        columnName = quote(columnName);
+        if (column != null) {
+            columnName = JDBC_DIALECT.convertType(columnName, column.typeName());
+        }
         final String minMaxQuery =
                 String.format(
-                        "SELECT MIN(%s), MAX(%s) FROM %s",
-                        quote(columnName), quote(columnName), quote(tableId));
+                        "SELECT MIN(%s), MAX(%s) FROM %s", columnName, columnName, quote(tableId));
         return jdbc.queryAndMap(
                 minMaxQuery,
                 rs -> {
@@ -96,12 +106,20 @@ public class PostgresUtils {
     }
 
     public static Object queryMin(
-            JdbcConnection jdbc, TableId tableId, String columnName, Object excludedLowerBound)
+            JdbcConnection jdbc,
+            TableId tableId,
+            String columnName,
+            Column column,
+            Object excludedLowerBound)
             throws SQLException {
+        columnName = quote(columnName);
+        if (column != null) {
+            columnName = JDBC_DIALECT.convertType(columnName, column.typeName());
+        }
         final String minQuery =
                 String.format(
                         "SELECT MIN(%s) FROM %s WHERE %s > ?",
-                        quote(columnName), quote(tableId), quote(columnName));
+                        columnName, quote(tableId), columnName);
         return jdbc.prepareQueryAndMap(
                 minQuery,
                 ps -> ps.setObject(1, excludedLowerBound),
@@ -141,10 +159,17 @@ public class PostgresUtils {
     }
 
     public static Object[] skipReadAndSortSampleData(
-            JdbcConnection jdbc, TableId tableId, String columnName, int inverseSamplingRate)
-            throws SQLException {
-        final String sampleQuery =
-                String.format("SELECT %s FROM %s", quote(columnName), quote(tableId));
+            JdbcConnection jdbc,
+            TableId tableId,
+            String columnName,
+            Column column,
+            int inverseSamplingRate)
+            throws Exception {
+        columnName = quote(columnName);
+        if (column != null) {
+            columnName = JDBC_DIALECT.convertType(columnName, column.typeName());
+        }
+        final String sampleQuery = String.format("SELECT %s FROM %s", columnName, quote(tableId));
 
         Statement stmt = null;
         ResultSet rs = null;
@@ -165,6 +190,9 @@ public class PostgresUtils {
                 if (count % 100000 == 0) {
                     log.info("Processing row index: {}", count);
                 }
+                if (Thread.currentThread().isInterrupted()) {
+                    throw new InterruptedException("Thread interrupted");
+                }
                 if (count % inverseSamplingRate == 0) {
                     results.add(rs.getObject(1));
                 }
@@ -198,10 +226,14 @@ public class PostgresUtils {
             JdbcConnection jdbc,
             TableId tableId,
             String splitColumnName,
+            Column splitColumn,
             int chunkSize,
             Object includedLowerBound)
             throws SQLException {
         String quotedColumn = quote(splitColumnName);
+        if (splitColumn != null) {
+            quotedColumn = JDBC_DIALECT.convertType(quotedColumn, splitColumn.typeName());
+        }
         String query =
                 String.format(
                         "SELECT MAX(%s) FROM ("
@@ -261,20 +293,38 @@ public class PostgresUtils {
     }
 
     /** Fetch current largest log sequence number (LSN) of the database. */
-    public static LsnOffset currentLsn(PostgresConnection connection) {
+    public static LsnOffset currentLsn(PostgresConnection jdbcConnection) {
+        Long lsn;
+        Long txId;
         try {
-            final Lsn lsn = Lsn.valueOf(connection.currentXLogLocation());
-            final long txId = connection.currentTransactionId().longValue();
-            return new LsnOffset(lsn, txId, null);
+            lsn = jdbcConnection.currentXLogLocation();
+            txId = jdbcConnection.currentTransactionId();
+            log.trace("Read xlogStart at '{}' from transaction '{}'", Lsn.valueOf(lsn), txId);
         } catch (SQLException e) {
-            throw new SeaTunnelException(e.getMessage(), e);
+            throw new SeaTunnelException("Error getting current Lsn/txId " + e.getMessage(), e);
         }
+
+        try {
+            jdbcConnection.commit();
+        } catch (SQLException e) {
+            throw new SeaTunnelException("JDBC connection fails to commit: " + e.getMessage(), e);
+        }
+
+        Map<String, String> offsetMap = new HashMap<>();
+        offsetMap.put(SourceInfo.LSN_KEY, lsn.toString());
+        if (txId != null) {
+            offsetMap.put(SourceInfo.TXID_KEY, txId.toString());
+        }
+        offsetMap.put(
+                SourceInfo.TIMESTAMP_USEC_KEY,
+                String.valueOf(Conversions.toEpochMicros(Instant.MIN)));
+        return LsnOffset.of(offsetMap);
     }
 
     /** Get split scan query for the given table. */
     public static String buildSplitScanQuery(
-            TableId tableId, SeaTunnelRowType rowType, boolean isFirstSplit, boolean isLastSplit) {
-        return buildSplitQuery(tableId, rowType, isFirstSplit, isLastSplit, -1, true);
+            Table table, SeaTunnelRowType rowType, boolean isFirstSplit, boolean isLastSplit) {
+        return buildSplitQuery(table, rowType, isFirstSplit, isLastSplit, -1, true);
     }
 
     /** Get table split data PreparedStatement. */
@@ -328,7 +378,7 @@ public class PostgresUtils {
     }
 
     private static String buildSplitQuery(
-            TableId tableId,
+            Table table,
             SeaTunnelRowType rowType,
             boolean isFirstSplit,
             boolean isLastSplit,
@@ -340,37 +390,37 @@ public class PostgresUtils {
             condition = null;
         } else if (isFirstSplit) {
             final StringBuilder sql = new StringBuilder();
-            addPrimaryKeyColumnsToCondition(rowType, sql, " <= ?");
+            addPrimaryKeyColumnsToCondition(table, rowType, sql, " <= ?");
             if (isScanningData) {
                 sql.append(" AND NOT (");
-                addPrimaryKeyColumnsToCondition(rowType, sql, " = ?");
+                addPrimaryKeyColumnsToCondition(table, rowType, sql, " = ?");
                 sql.append(")");
             }
             condition = sql.toString();
         } else if (isLastSplit) {
             final StringBuilder sql = new StringBuilder();
-            addPrimaryKeyColumnsToCondition(rowType, sql, " >= ?");
+            addPrimaryKeyColumnsToCondition(table, rowType, sql, " >= ?");
             condition = sql.toString();
         } else {
             final StringBuilder sql = new StringBuilder();
-            addPrimaryKeyColumnsToCondition(rowType, sql, " >= ?");
+            addPrimaryKeyColumnsToCondition(table, rowType, sql, " >= ?");
             if (isScanningData) {
                 sql.append(" AND NOT (");
-                addPrimaryKeyColumnsToCondition(rowType, sql, " = ?");
+                addPrimaryKeyColumnsToCondition(table, rowType, sql, " = ?");
                 sql.append(")");
             }
             sql.append(" AND ");
-            addPrimaryKeyColumnsToCondition(rowType, sql, " <= ?");
+            addPrimaryKeyColumnsToCondition(table, rowType, sql, " <= ?");
             condition = sql.toString();
         }
 
         if (isScanningData) {
             return buildSelectWithRowLimits(
-                    tableId, limitSize, "*", Optional.ofNullable(condition), Optional.empty());
+                    table.id(), limitSize, "*", Optional.ofNullable(condition), Optional.empty());
         } else {
             final String orderBy = String.join(", ", rowType.getFieldNames());
             return buildSelectWithBoundaryRowLimits(
-                    tableId,
+                    table.id(),
                     limitSize,
                     getPrimaryKeyColumnsProjection(rowType),
                     getMaxPrimaryKeyColumnsProjection(rowType),
@@ -441,11 +491,14 @@ public class PostgresUtils {
     }
 
     private static void addPrimaryKeyColumnsToCondition(
-            SeaTunnelRowType rowType, StringBuilder sql, String predicate) {
-        for (Iterator<String> fieldNamesIt = Arrays.stream(rowType.getFieldNames()).iterator();
-                fieldNamesIt.hasNext(); ) {
-            sql.append(quote(fieldNamesIt.next())).append(predicate);
-            if (fieldNamesIt.hasNext()) {
+            Table table, SeaTunnelRowType rowType, StringBuilder sql, String predicate) {
+        for (int i = 0; i < rowType.getTotalFields(); i++) {
+            String fieldName = quote(rowType.getFieldName(i));
+            fieldName =
+                    JDBC_DIALECT.convertType(
+                            fieldName, table.columnWithName(rowType.getFieldName(i)).typeName());
+            sql.append(fieldName).append(predicate);
+            if (i < rowType.getTotalFields() - 1) {
                 sql.append(" AND ");
             }
         }
