@@ -17,7 +17,11 @@
 
 package org.apache.seatunnel.connectors.doris.sink.writer;
 
+import org.apache.seatunnel.shade.com.fasterxml.jackson.core.type.TypeReference;
+
 import org.apache.seatunnel.api.table.catalog.TablePath;
+import org.apache.seatunnel.common.utils.ExceptionUtils;
+import org.apache.seatunnel.common.utils.JsonUtils;
 import org.apache.seatunnel.connectors.doris.config.DorisConfig;
 import org.apache.seatunnel.connectors.doris.exception.DorisConnectorErrorCode;
 import org.apache.seatunnel.connectors.doris.exception.DorisConnectorException;
@@ -31,9 +35,9 @@ import org.apache.http.entity.InputStreamEntity;
 import org.apache.http.impl.client.CloseableHttpClient;
 import org.apache.http.util.EntityUtils;
 
-import com.fasterxml.jackson.core.type.TypeReference;
 import com.fasterxml.jackson.databind.ObjectMapper;
 import com.google.common.util.concurrent.ThreadFactoryBuilder;
+import lombok.Getter;
 import lombok.extern.slf4j.Slf4j;
 
 import java.io.IOException;
@@ -64,23 +68,23 @@ public class DorisStreamLoad implements Serializable {
     private static final String ABORT_URL_PATTERN = "http://%s/api/%s/_stream_load_2pc";
     private static final String JOB_EXIST_FINISHED = "FINISHED";
     private final String loadUrlStr;
-    private final String hostPort;
+    @Getter private final String hostPort;
     private final String abortUrlStr;
     private final String user;
     private final String passwd;
-    private final String db;
+    @Getter private final String db;
     private final String table;
     private final boolean enable2PC;
     private final boolean enableDelete;
     private final Properties streamLoadProp;
     private final RecordStream recordStream;
-    private Future<CloseableHttpResponse> pendingLoadFuture;
+    @Getter private Future<CloseableHttpResponse> pendingLoadFuture;
     private final CloseableHttpClient httpClient;
     private final ExecutorService executorService;
     private volatile boolean loadBatchFirstRecord;
     private volatile boolean loading = false;
     private String label;
-    private long recordCount = 0;
+    @Getter private long recordCount = 0;
 
     public DorisStreamLoad(
             String hostPort,
@@ -115,18 +119,6 @@ public class DorisStreamLoad implements Serializable {
         loadBatchFirstRecord = true;
     }
 
-    public String getDb() {
-        return db;
-    }
-
-    public String getHostPort() {
-        return hostPort;
-    }
-
-    public Future<CloseableHttpResponse> getPendingLoadFuture() {
-        return pendingLoadFuture;
-    }
-
     public void abortPreCommit(String labelSuffix, long chkID) throws Exception {
         long startChkID = chkID;
         log.info("abort for labelSuffix {}. start chkId {}.", labelSuffix, chkID);
@@ -196,10 +188,6 @@ public class DorisStreamLoad implements Serializable {
         recordCount++;
     }
 
-    public long getRecordCount() {
-        return recordCount;
-    }
-
     public String getLoadFailedMsg() {
         if (!loading) {
             return null;
@@ -209,7 +197,7 @@ public class DorisStreamLoad implements Serializable {
             try {
                 errorMessage = handlePreCommitResponse(pendingLoadFuture.get()).getMessage();
             } catch (Exception e) {
-                errorMessage = e.getMessage();
+                errorMessage = ExceptionUtils.getMessage(e);
             }
             recordStream.setErrorMessageByStreamLoad(errorMessage);
             return errorMessage;
@@ -300,10 +288,9 @@ public class DorisStreamLoad implements Serializable {
                     "Fail to abort transaction " + txnID + " with url " + abortUrlStr);
         }
 
-        ObjectMapper mapper = new ObjectMapper();
         String loadResult = EntityUtils.toString(response.getEntity());
         Map<String, String> res =
-                mapper.readValue(loadResult, new TypeReference<HashMap<String, String>>() {});
+                JsonUtils.parseObject(loadResult, new TypeReference<HashMap<String, String>>() {});
         if (!LoadStatus.SUCCESS.equals(res.get("status"))) {
             if (ResponseUtil.isCommitted(res.get("msg"))) {
                 throw new DorisConnectorException(
