@@ -40,6 +40,8 @@ import org.apache.seatunnel.connectors.seatunnel.elasticsearch.catalog.ElasticSe
 import org.apache.seatunnel.connectors.seatunnel.elasticsearch.client.EsRestClient;
 import org.apache.seatunnel.connectors.seatunnel.elasticsearch.client.EsType;
 import org.apache.seatunnel.connectors.seatunnel.elasticsearch.config.SourceConfig;
+import org.apache.seatunnel.connectors.seatunnel.elasticsearch.exception.ElasticsearchConnectorErrorCode;
+import org.apache.seatunnel.connectors.seatunnel.elasticsearch.exception.ElasticsearchConnectorException;
 
 import org.apache.commons.collections4.CollectionUtils;
 
@@ -50,6 +52,7 @@ import java.util.Arrays;
 import java.util.Collections;
 import java.util.List;
 import java.util.Map;
+import java.util.stream.Collectors;
 
 @Slf4j
 public class ElasticsearchSource
@@ -58,30 +61,60 @@ public class ElasticsearchSource
                 SupportParallelism,
                 SupportColumnProjection {
 
-    private final ReadonlyConfig config;
-
-    private CatalogTable catalogTable;
-
-    private List<String> source;
-
-    private Map<String, String> arrayColumn;
+    private final List<SourceConfig> sourceConfigList;
+    private final ReadonlyConfig connectionConfig;
 
     public ElasticsearchSource(ReadonlyConfig config) {
-        this.config = config;
-        if (config.getOptional(TableSchemaOptions.SCHEMA).isPresent()) {
+        this.connectionConfig = config;
+        boolean multiSource = config.getOptional(SourceConfig.INDEX_LIST).isPresent();
+        boolean singleSource = config.getOptional(SourceConfig.INDEX).isPresent();
+        if (multiSource && singleSource) {
+            log.warn(
+                    "Elasticsearch Source config warn: when both 'index' and 'index_list' are present in the configuration, only the 'index_list' configuration will take effect");
+        }
+        if (!multiSource && !singleSource) {
+            throw new ElasticsearchConnectorException(
+                    ElasticsearchConnectorErrorCode.SOURCE_CONFIG_ERROR_01,
+                    ElasticsearchConnectorErrorCode.SOURCE_CONFIG_ERROR_01.getDescription());
+        }
+        if (multiSource) {
+            this.sourceConfigList = createMultiSource(config);
+        } else {
+            this.sourceConfigList = Collections.singletonList(parseOneIndexQueryConfig(config));
+        }
+    }
+
+    private List<SourceConfig> createMultiSource(ReadonlyConfig config) {
+        List<Map<String, Object>> configMaps = config.get(SourceConfig.INDEX_LIST);
+        List<ReadonlyConfig> configList =
+                configMaps.stream().map(ReadonlyConfig::fromMap).collect(Collectors.toList());
+        List<SourceConfig> sourceConfigList = new ArrayList<>(configList.size());
+        for (ReadonlyConfig readonlyConfig : configList) {
+            SourceConfig sourceConfig = parseOneIndexQueryConfig(readonlyConfig);
+            sourceConfigList.add(sourceConfig);
+        }
+        return sourceConfigList;
+    }
+
+    private SourceConfig parseOneIndexQueryConfig(ReadonlyConfig readonlyConfig) {
+
+        Map<String, Object> query = readonlyConfig.get(SourceConfig.QUERY);
+        String index = readonlyConfig.get(SourceConfig.INDEX);
+
+        CatalogTable catalogTable;
+        List<String> source;
+        Map<String, String> arrayColumn;
+
+        if (readonlyConfig.getOptional(TableSchemaOptions.SCHEMA).isPresent()) {
             // todo: We need to remove the schema in ES.
             log.warn(
-                    "The schema config in ElasticSearch sink is deprecated, please use source config instead!");
-            catalogTable = CatalogTableUtil.buildWithConfig(config);
+                    "The schema config in ElasticSearch source/sink is deprecated, please use source config instead!");
+            catalogTable = CatalogTableUtil.buildWithConfig(readonlyConfig);
             source = Arrays.asList(catalogTable.getSeaTunnelRowType().getFieldNames());
         } else {
-            source = config.get(SourceConfig.SOURCE);
-            arrayColumn = config.get(SourceConfig.ARRAY_COLUMN);
-            EsRestClient esRestClient = EsRestClient.createInstance(config);
-            Map<String, BasicTypeDefine<EsType>> esFieldType =
-                    esRestClient.getFieldTypeMapping(config.get(SourceConfig.INDEX), source);
-            esRestClient.close();
-
+            source = readonlyConfig.get(SourceConfig.SOURCE);
+            arrayColumn = readonlyConfig.get(SourceConfig.ARRAY_COLUMN);
+            Map<String, BasicTypeDefine<EsType>> esFieldType = getFieldTypeMapping(index, source);
             if (CollectionUtils.isEmpty(source)) {
                 source = new ArrayList<>(esFieldType.keySet());
             }
@@ -90,26 +123,48 @@ public class ElasticsearchSource
 
             for (int i = 0; i < source.size(); i++) {
                 String key = source.get(i);
+                String sourceType = esFieldType.get(key).getDataType();
                 if (arrayColumn.containsKey(key)) {
                     String value = arrayColumn.get(key);
                     SeaTunnelDataType<?> dataType =
                             SeaTunnelDataTypeConvertorUtil.deserializeSeaTunnelDataType(key, value);
-                    builder.column(PhysicalColumn.of(key, dataType, 0, true, null, null));
+                    builder.column(
+                            PhysicalColumn.of(
+                                    key, dataType, 0L, true, null, null, sourceType, null));
                     continue;
                 }
 
                 builder.column(
-                        PhysicalColumn.of(source.get(i), fieldTypes[i], 0, true, null, null));
+                        PhysicalColumn.of(
+                                source.get(i),
+                                fieldTypes[i],
+                                0L,
+                                true,
+                                null,
+                                null,
+                                sourceType,
+                                null));
             }
             catalogTable =
                     CatalogTable.of(
-                            TableIdentifier.of(
-                                    "elasticsearch", null, config.get(SourceConfig.INDEX)),
+                            TableIdentifier.of("elasticsearch", null, index),
                             builder.build(),
                             Collections.emptyMap(),
                             Collections.emptyList(),
                             "");
         }
+
+        String scrollTime = readonlyConfig.get(SourceConfig.SCROLL_TIME);
+        int scrollSize = readonlyConfig.get(SourceConfig.SCROLL_SIZE);
+        SourceConfig sourceConfig = new SourceConfig();
+        sourceConfig.setSource(source);
+        sourceConfig.setCatalogTable(catalogTable);
+        sourceConfig.setQuery(query);
+        sourceConfig.setScrollTime(scrollTime);
+        sourceConfig.setScrollSize(scrollSize);
+        sourceConfig.setIndex(index);
+        sourceConfig.setCatalogTable(catalogTable);
+        return sourceConfig;
     }
 
     @Override
@@ -124,21 +179,23 @@ public class ElasticsearchSource
 
     @Override
     public List<CatalogTable> getProducedCatalogTables() {
-        return Collections.singletonList(catalogTable);
+        return sourceConfigList.stream()
+                .map(SourceConfig::getCatalogTable)
+                .collect(Collectors.toList());
     }
 
     @Override
     public SourceReader<SeaTunnelRow, ElasticsearchSourceSplit> createReader(
             SourceReader.Context readerContext) {
-        return new ElasticsearchSourceReader(
-                readerContext, config, catalogTable.getSeaTunnelRowType());
+        return new ElasticsearchSourceReader(readerContext, connectionConfig);
     }
 
     @Override
     public SourceSplitEnumerator<ElasticsearchSourceSplit, ElasticsearchSourceState>
             createEnumerator(
                     SourceSplitEnumerator.Context<ElasticsearchSourceSplit> enumeratorContext) {
-        return new ElasticsearchSourceSplitEnumerator(enumeratorContext, config, source);
+        return new ElasticsearchSourceSplitEnumerator(
+                enumeratorContext, connectionConfig, sourceConfigList);
     }
 
     @Override
@@ -147,7 +204,7 @@ public class ElasticsearchSource
                     SourceSplitEnumerator.Context<ElasticsearchSourceSplit> enumeratorContext,
                     ElasticsearchSourceState sourceState) {
         return new ElasticsearchSourceSplitEnumerator(
-                enumeratorContext, sourceState, config, source);
+                enumeratorContext, sourceState, connectionConfig, sourceConfigList);
     }
 
     @VisibleForTesting
@@ -162,4 +219,13 @@ public class ElasticsearchSource
         }
         return fieldTypes;
     }
+
+    private Map<String, BasicTypeDefine<EsType>> getFieldTypeMapping(
+            String index, List<String> source) {
+        // EsRestClient#getFieldTypeMapping may throw runtime exception
+        // so here we use try-resources-finally to close the resource
+        try (EsRestClient esRestClient = EsRestClient.createInstance(connectionConfig)) {
+            return esRestClient.getFieldTypeMapping(index, source);
+        }
+    }
 }
