@@ -27,6 +27,7 @@ import org.apache.seatunnel.connectors.seatunnel.fake.exception.FakeConnectorExc
 import lombok.AllArgsConstructor;
 import lombok.Builder;
 import lombok.Getter;
+import lombok.Setter;
 
 import java.io.Serializable;
 import java.util.ArrayList;
@@ -38,6 +39,7 @@ import static org.apache.seatunnel.connectors.seatunnel.fake.config.FakeOption.B
 import static org.apache.seatunnel.connectors.seatunnel.fake.config.FakeOption.BIGINT_MAX;
 import static org.apache.seatunnel.connectors.seatunnel.fake.config.FakeOption.BIGINT_MIN;
 import static org.apache.seatunnel.connectors.seatunnel.fake.config.FakeOption.BIGINT_TEMPLATE;
+import static org.apache.seatunnel.connectors.seatunnel.fake.config.FakeOption.BINARY_VECTOR_DIMENSION;
 import static org.apache.seatunnel.connectors.seatunnel.fake.config.FakeOption.BYTES_LENGTH;
 import static org.apache.seatunnel.connectors.seatunnel.fake.config.FakeOption.DATE_DAY_TEMPLATE;
 import static org.apache.seatunnel.connectors.seatunnel.fake.config.FakeOption.DATE_MONTH_TEMPLATE;
@@ -73,6 +75,9 @@ import static org.apache.seatunnel.connectors.seatunnel.fake.config.FakeOption.T
 import static org.apache.seatunnel.connectors.seatunnel.fake.config.FakeOption.TINYINT_MAX;
 import static org.apache.seatunnel.connectors.seatunnel.fake.config.FakeOption.TINYINT_MIN;
 import static org.apache.seatunnel.connectors.seatunnel.fake.config.FakeOption.TINYINT_TEMPLATE;
+import static org.apache.seatunnel.connectors.seatunnel.fake.config.FakeOption.VECTOR_DIMENSION;
+import static org.apache.seatunnel.connectors.seatunnel.fake.config.FakeOption.VECTOR_FLOAT_MAX;
+import static org.apache.seatunnel.connectors.seatunnel.fake.config.FakeOption.VECTOR_FLOAT_MIN;
 
 @Builder
 @Getter
@@ -115,6 +120,14 @@ public class FakeConfig implements Serializable {
 
     @Builder.Default private double doubleMax = DOUBLE_MAX.defaultValue();
 
+    @Builder.Default private float vectorFloatMin = VECTOR_FLOAT_MIN.defaultValue();
+
+    @Builder.Default private float vectorFloatMax = VECTOR_FLOAT_MAX.defaultValue();
+
+    @Builder.Default private int vectorDimension = VECTOR_DIMENSION.defaultValue();
+
+    @Builder.Default private int binaryVectorDimension = BINARY_VECTOR_DIMENSION.defaultValue();
+
     @Builder.Default private FakeOption.FakeMode stringFakeMode = STRING_FAKE_MODE.defaultValue();
 
     @Builder.Default private FakeOption.FakeMode tinyintFakeMode = TINYINT_FAKE_MODE.defaultValue();
@@ -157,6 +170,8 @@ public class FakeConfig implements Serializable {
         builder.splitReadInterval(readonlyConfig.get(SPLIT_READ_INTERVAL));
         builder.mapSize(readonlyConfig.get(MAP_SIZE));
         builder.arraySize(readonlyConfig.get(ARRAY_SIZE));
+        builder.vectorDimension(readonlyConfig.get(VECTOR_DIMENSION));
+        builder.binaryVectorDimension(readonlyConfig.get(BINARY_VECTOR_DIMENSION));
         builder.bytesLength(readonlyConfig.get(BYTES_LENGTH));
         builder.stringLength(readonlyConfig.get(STRING_LENGTH));
 
@@ -389,6 +404,40 @@ public class FakeConfig implements Serializable {
                             builder.doubleMax(doubleMax);
                         });
 
+        readonlyConfig
+                .getOptional(VECTOR_FLOAT_MIN)
+                .ifPresent(
+                        vectorFloatMin -> {
+                            if (vectorFloatMin < VECTOR_FLOAT_MIN.defaultValue()
+                                    || vectorFloatMin > VECTOR_FLOAT_MAX.defaultValue()) {
+                                throw new FakeConnectorException(
+                                        CommonErrorCodeDeprecated.ILLEGAL_ARGUMENT,
+                                        VECTOR_FLOAT_MIN.key()
+                                                + " should >= "
+                                                + VECTOR_FLOAT_MIN.defaultValue()
+                                                + " and <= "
+                                                + VECTOR_FLOAT_MAX.defaultValue());
+                            }
+                            builder.vectorFloatMin(vectorFloatMin);
+                        });
+
+        readonlyConfig
+                .getOptional(VECTOR_FLOAT_MAX)
+                .ifPresent(
+                        vectorFloatMax -> {
+                            if (vectorFloatMax < VECTOR_FLOAT_MIN.defaultValue()
+                                    || vectorFloatMax > VECTOR_FLOAT_MAX.defaultValue()) {
+                                throw new FakeConnectorException(
+                                        CommonErrorCodeDeprecated.ILLEGAL_ARGUMENT,
+                                        VECTOR_FLOAT_MAX.key()
+                                                + " should >= "
+                                                + VECTOR_FLOAT_MIN.defaultValue()
+                                                + " and <= "
+                                                + VECTOR_FLOAT_MAX.defaultValue());
+                            }
+                            builder.vectorFloatMax(vectorFloatMax);
+                        });
+
         readonlyConfig.getOptional(STRING_FAKE_MODE).ifPresent(builder::stringFakeMode);
         readonlyConfig.getOptional(TINYINT_FAKE_MODE).ifPresent(builder::tinyintFakeMode);
         readonlyConfig.getOptional(SMALLINT_FAKE_MODE).ifPresent(builder::smallintFakeMode);
@@ -403,6 +452,7 @@ public class FakeConfig implements Serializable {
     }
 
     @Getter
+    @Setter
     @AllArgsConstructor
     public static class RowData implements Serializable {
         static final String KEY_KIND = "kind";
