@@ -21,13 +21,13 @@ package org.apache.seatunnel.connectors.seatunnel.iceberg.utils;
 
 import org.apache.seatunnel.api.configuration.ReadonlyConfig;
 import org.apache.seatunnel.api.table.catalog.CatalogTable;
+import org.apache.seatunnel.api.table.catalog.Column;
 import org.apache.seatunnel.api.table.catalog.TablePath;
 import org.apache.seatunnel.api.table.catalog.TableSchema;
 import org.apache.seatunnel.api.table.catalog.exception.CatalogException;
 import org.apache.seatunnel.api.table.catalog.exception.DatabaseNotExistException;
 import org.apache.seatunnel.api.table.catalog.exception.TableAlreadyExistException;
 import org.apache.seatunnel.api.table.type.SeaTunnelDataType;
-import org.apache.seatunnel.api.table.type.SeaTunnelRowType;
 import org.apache.seatunnel.connectors.seatunnel.iceberg.config.SinkConfig;
 import org.apache.seatunnel.connectors.seatunnel.iceberg.data.IcebergTypeMapper;
 import org.apache.seatunnel.connectors.seatunnel.iceberg.sink.schema.SchemaAddColumn;
@@ -36,11 +36,9 @@ import org.apache.seatunnel.connectors.seatunnel.iceberg.sink.schema.SchemaChang
 import org.apache.seatunnel.connectors.seatunnel.iceberg.sink.schema.SchemaDeleteColumn;
 import org.apache.seatunnel.connectors.seatunnel.iceberg.sink.schema.SchemaModifyColumn;
 
-import org.apache.commons.collections.CollectionUtils;
 import org.apache.iceberg.PartitionSpec;
 import org.apache.iceberg.Schema;
 import org.apache.iceberg.Table;
-import org.apache.iceberg.TableProperties;
 import org.apache.iceberg.UpdateSchema;
 import org.apache.iceberg.catalog.Catalog;
 import org.apache.iceberg.catalog.TableIdentifier;
@@ -55,16 +53,17 @@ import com.google.common.annotations.VisibleForTesting;
 import lombok.extern.slf4j.Slf4j;
 
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.HashMap;
-import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
-import java.util.Objects;
 import java.util.Optional;
 import java.util.Set;
+import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.atomic.AtomicReference;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
+import java.util.stream.Collectors;
 
 import static java.util.stream.Collectors.toList;
 
@@ -101,33 +100,23 @@ public class SchemaUtils {
             throws TableAlreadyExistException, DatabaseNotExistException, CatalogException {
         TableSchema tableSchema = table.getTableSchema();
         // Convert to iceberg schema
-        Schema schema = toIcebergSchema(tableSchema.toPhysicalRowDataType(), readonlyConfig);
+        Schema schema = toIcebergSchema(tableSchema, readonlyConfig);
         // Convert sink config
         SinkConfig config = new SinkConfig(readonlyConfig);
         // build auto create table
         Map<String, String> options = new HashMap<>(table.getOptions());
-        options.put(TableProperties.FORMAT_VERSION, "2");
         // override
         options.putAll(config.getAutoCreateProps());
         return createTable(catalog, toIcebergTableIdentifier(tablePath), config, schema, options);
     }
 
-    /**
-     * For local test
-     *
-     * @param catalog
-     * @param tableIdentifier
-     * @param config
-     * @param rowType
-     * @return
-     */
     public static Table autoCreateTable(
             Catalog catalog,
             TableIdentifier tableIdentifier,
             SinkConfig config,
-            SeaTunnelRowType rowType) {
+            TableSchema tableSchema) {
         // Generate struct type
-        Schema schema = toIcebergSchema(rowType, config.getReadonlyConfig());
+        Schema schema = toIcebergSchema(tableSchema, config.getReadonlyConfig());
         return createTable(catalog, tableIdentifier, config, schema, config.getAutoCreateProps());
     }
 
@@ -169,50 +158,31 @@ public class SchemaUtils {
 
     @VisibleForTesting
     @NotNull protected static Schema toIcebergSchema(
-            SeaTunnelRowType rowType, ReadonlyConfig readonlyConfig) {
-        Types.StructType structType = SchemaUtils.toIcebergType(rowType).asStructType();
-        Set<Integer> identifierFieldIds = new HashSet<>();
-        if (Objects.nonNull(readonlyConfig)) {
-            List<String> pks =
-                    SinkConfig.stringToList(readonlyConfig.get(SinkConfig.TABLE_PRIMARY_KEYS), ",");
-            if (CollectionUtils.isNotEmpty(pks)) {
-                for (String pk : pks) {
-                    Optional<Integer> pkId =
-                            structType.fields().stream()
-                                    .filter(nestedField -> nestedField.name().equals(pk))
-                                    .map(nestedField -> nestedField.fieldId())
-                                    .findFirst();
-                    if (!pkId.isPresent()) {
-                        throw new IllegalArgumentException(
-                                String.format(
-                                        "iceberg table pk:%s not present in the incoming struct",
-                                        pk));
-                    }
-                    identifierFieldIds.add(pkId.get());
-                }
-            }
-        }
+            TableSchema tableSchema, ReadonlyConfig readonlyConfig) {
+        Types.StructType structType = SchemaUtils.toIcebergType(tableSchema);
+        Set<Integer> identifierFieldIds =
+                readonlyConfig.getOptional(SinkConfig.TABLE_PRIMARY_KEYS)
+                        .map(e -> SinkConfig.stringToList(e, ","))
+                        .orElseGet(
+                                () ->
+                                        Optional.ofNullable(tableSchema.getPrimaryKey())
+                                                .map(e -> e.getColumnNames())
+                                                .orElse(Collections.emptyList()))
+                        .stream()
+                        .map(f -> structType.field(f).fieldId())
+                        .collect(Collectors.toSet());
         List<Types.NestedField> fields = new ArrayList<>();
         structType
                 .fields()
                 .forEach(
-                        field -> {
-                            fields.add(
-                                    identifierFieldIds.contains(field.fieldId())
-                                            ? field.asRequired()
-                                            : field.asOptional());
-                        });
+                        field ->
+                                fields.add(
+                                        identifierFieldIds.contains(field.fieldId())
+                                                ? field.asRequired()
+                                                : field.asOptional()));
         return new Schema(fields, identifierFieldIds);
     }
 
-    public static TableIdentifier toIcebergTableIdentifierFromCatalogTable(
-            CatalogTable catalogTable) {
-        org.apache.seatunnel.api.table.catalog.TableIdentifier tableIdentifier =
-                catalogTable.getTableId();
-        return TableIdentifier.of(
-                tableIdentifier.getDatabaseName(), tableIdentifier.getTableName());
-    }
-
     public static TableIdentifier toIcebergTableIdentifier(TablePath tablePath) {
         return TableIdentifier.of(tablePath.getDatabaseName(), tablePath.getTableName());
     }
@@ -221,12 +191,7 @@ public class SchemaUtils {
         return TablePath.of(tableIdentifier.namespace().toString(), tableIdentifier.name());
     }
 
-    /**
-     * Commit table schema updates
-     *
-     * @param table
-     * @param wrapper
-     */
+    /** Commit table schema updates */
     private static void commitSchemaUpdates(Table table, SchemaChangeWrapper wrapper) {
         // get the latest schema in case another process updated it
         table.refresh();
@@ -242,14 +207,17 @@ public class SchemaUtils {
                         .filter(updateType -> !typeMatches(table.schema(), updateType))
                         .collect(toList());
 
-        // filter out columns that have the updated type
+        // filter out columns that have already been deleted
         List<SchemaDeleteColumn> deleteColumns =
                 wrapper.deleteColumns().stream()
                         .filter(deleteColumn -> findColumns(table.schema(), deleteColumn))
                         .collect(toList());
 
-        // Rename column name
-        List<SchemaChangeColumn> changeColumns = wrapper.changeColumns().stream().collect(toList());
+        // filter out columns that have already been changed
+        List<SchemaChangeColumn> changeColumns =
+                wrapper.changeColumns().stream()
+                        .filter(changeColumn -> findColumns(table.schema(), changeColumn))
+                        .collect(toList());
 
         if (addColumns.isEmpty()
                 && modifyColumns.isEmpty()
@@ -274,7 +242,7 @@ public class SchemaUtils {
         log.info("Schema for table {} updated with new columns", table.name());
     }
 
-    private static boolean columnExists(org.apache.iceberg.Schema schema, SchemaAddColumn update) {
+    private static boolean columnExists(Schema schema, SchemaAddColumn update) {
         Types.StructType struct =
                 update.parentName() == null
                         ? schema.asStruct()
@@ -282,26 +250,44 @@ public class SchemaUtils {
         return struct.field(update.name()) != null;
     }
 
-    private static boolean typeMatches(
-            org.apache.iceberg.Schema schema, SchemaModifyColumn update) {
+    private static boolean typeMatches(Schema schema, SchemaModifyColumn update) {
         return schema.findType(update.name()).typeId() == update.type().typeId();
     }
 
-    private static boolean findColumns(
-            org.apache.iceberg.Schema schema, SchemaDeleteColumn deleteColumn) {
+    private static boolean findColumns(Schema schema, SchemaDeleteColumn deleteColumn) {
         return schema.findField(deleteColumn.name()) != null;
     }
 
+    private static boolean findColumns(
+            org.apache.iceberg.Schema schema, SchemaChangeColumn changeColumn) {
+        return schema.findField(changeColumn.oldName()) != null;
+    }
+
     public static SeaTunnelDataType<?> toSeaTunnelType(String fieldName, Type type) {
         return IcebergTypeMapper.mapping(fieldName, type);
     }
 
-    public static Type toIcebergType(SeaTunnelDataType rowType) {
+    public static Type toIcebergType(SeaTunnelDataType<?> rowType) {
         return IcebergTypeMapper.toIcebergType(rowType);
     }
 
-    public static PartitionSpec createPartitionSpec(
-            org.apache.iceberg.Schema schema, List<String> partitionBy) {
+    public static Types.StructType toIcebergType(TableSchema tableSchema) {
+        List<Types.NestedField> structFields = new ArrayList<>();
+        AtomicInteger idIncrementer = new AtomicInteger(1);
+        for (Column column : tableSchema.getColumns()) {
+            Types.NestedField icebergField =
+                    Types.NestedField.of(
+                            idIncrementer.getAndIncrement(),
+                            column.isNullable(),
+                            column.getName(),
+                            IcebergTypeMapper.toIcebergType(column.getDataType(), idIncrementer),
+                            column.getComment());
+            structFields.add(icebergField);
+        }
+        return Types.StructType.of(structFields);
+    }
+
+    public static PartitionSpec createPartitionSpec(Schema schema, List<String> partitionBy) {
         if (partitionBy.isEmpty()) {
             return PartitionSpec.unpartitioned();
         }
