@@ -17,11 +17,11 @@
 
 package org.apache.seatunnel.connectors.seatunnel.influxdb.sink;
 
-import org.apache.seatunnel.shade.com.typesafe.config.Config;
-
+import org.apache.seatunnel.api.sink.SupportMultiTableSinkWriter;
 import org.apache.seatunnel.api.table.type.SeaTunnelRow;
 import org.apache.seatunnel.api.table.type.SeaTunnelRowType;
 import org.apache.seatunnel.common.exception.CommonErrorCodeDeprecated;
+import org.apache.seatunnel.common.utils.JsonUtils;
 import org.apache.seatunnel.connectors.seatunnel.common.sink.AbstractSinkWriter;
 import org.apache.seatunnel.connectors.seatunnel.influxdb.client.InfluxDBClient;
 import org.apache.seatunnel.connectors.seatunnel.influxdb.config.SinkConfig;
@@ -36,7 +36,6 @@ import org.influxdb.dto.Point;
 
 import lombok.SneakyThrows;
 import lombok.extern.slf4j.Slf4j;
-import okhttp3.internal.concurrent.TaskRunner;
 
 import java.io.IOException;
 import java.net.ConnectException;
@@ -45,7 +44,8 @@ import java.util.List;
 import java.util.Optional;
 
 @Slf4j
-public class InfluxDBSinkWriter extends AbstractSinkWriter<SeaTunnelRow, Void> {
+public class InfluxDBSinkWriter extends AbstractSinkWriter<SeaTunnelRow, Void>
+        implements SupportMultiTableSinkWriter {
 
     private final Serializer serializer;
     private InfluxDB influxdb;
@@ -53,9 +53,10 @@ public class InfluxDBSinkWriter extends AbstractSinkWriter<SeaTunnelRow, Void> {
     private final List<Point> batchList;
     private volatile Exception flushException;
 
-    public InfluxDBSinkWriter(Config pluginConfig, SeaTunnelRowType seaTunnelRowType)
+    public InfluxDBSinkWriter(SinkConfig sinkConfig, SeaTunnelRowType seaTunnelRowType)
             throws ConnectException {
-        this.sinkConfig = SinkConfig.loadConfig(pluginConfig);
+        this.sinkConfig = sinkConfig;
+        log.info("sinkConfig is {}", JsonUtils.toJsonString(sinkConfig));
         this.serializer =
                 new DefaultSerializer(
                         seaTunnelRowType,
@@ -89,8 +90,6 @@ public class InfluxDBSinkWriter extends AbstractSinkWriter<SeaTunnelRow, Void> {
         if (influxdb != null) {
             influxdb.close();
             influxdb = null;
-            // TODO we should remove shutdown logic when supported closed part task
-            ((TaskRunner.RealBackend) TaskRunner.INSTANCE.getBackend()).shutdown();
         }
     }
 
