@@ -23,21 +23,16 @@ import org.apache.seatunnel.api.table.catalog.exception.CatalogException;
 import org.apache.seatunnel.api.table.catalog.exception.DatabaseNotExistException;
 import org.apache.seatunnel.api.table.catalog.exception.TableAlreadyExistException;
 import org.apache.seatunnel.common.utils.JdbcUrlUtil;
+import org.apache.seatunnel.common.utils.SeaTunnelException;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.catalog.oracle.OracleCatalog;
 
+import java.sql.SQLException;
 import java.util.List;
 
 import static org.apache.seatunnel.shade.com.google.common.base.Preconditions.checkNotNull;
 
 public class OceanBaseOracleCatalog extends OracleCatalog {
 
-    static {
-        EXCLUDED_SCHEMAS.add("oceanbase");
-        EXCLUDED_SCHEMAS.add("LBACSYS");
-        EXCLUDED_SCHEMAS.add("ORAAUDITOR");
-        EXCLUDED_SCHEMAS.add("SYS");
-    }
-
     public OceanBaseOracleCatalog(
             String catalogName,
             String username,
@@ -59,12 +54,13 @@ public class OceanBaseOracleCatalog extends OracleCatalog {
 
     @Override
     public boolean tableExists(TablePath tablePath) throws CatalogException {
-        if (EXCLUDED_SCHEMAS.contains(tablePath.getSchemaName())) {
-            return false;
+        try {
+            return querySQLResultExists(
+                    this.getUrlFromDatabaseName(tablePath.getDatabaseName()),
+                    getTableWithConditionSql(tablePath));
+        } catch (SQLException e) {
+            throw new SeaTunnelException("Failed to querySQLResult", e);
         }
-        return querySQLResultExists(
-                this.getUrlFromDatabaseName(tablePath.getDatabaseName()),
-                getTableWithConditionSql(tablePath));
     }
 
     @Override
