@@ -72,25 +72,33 @@ public class JdbcColumnConverter {
 
     public static List<Column> convert(DatabaseMetaData metadata, TablePath tablePath)
             throws SQLException {
-        ResultSet columnsResultSet =
+        List<Column> columns = new ArrayList<>();
+
+        try (ResultSet columnsResultSet =
                 metadata.getColumns(
                         tablePath.getDatabaseName(),
                         tablePath.getSchemaName(),
                         tablePath.getTableName(),
-                        null);
+                        null)) {
 
-        List<Column> columns = new ArrayList<>();
-        while (columnsResultSet.next()) {
-            String columnName = columnsResultSet.getString("COLUMN_NAME");
-            int jdbcType = columnsResultSet.getInt("DATA_TYPE");
-            String nativeType = columnsResultSet.getString("TYPE_NAME");
-            int columnSize = columnsResultSet.getInt("COLUMN_SIZE");
-            int decimalDigits = columnsResultSet.getInt("DECIMAL_DIGITS");
-            int nullable = columnsResultSet.getInt("NULLABLE");
+            while (columnsResultSet.next()) {
+                String columnName = columnsResultSet.getString("COLUMN_NAME");
+                int jdbcType = columnsResultSet.getInt("DATA_TYPE");
+                String nativeType = columnsResultSet.getString("TYPE_NAME");
+                int columnSize = columnsResultSet.getInt("COLUMN_SIZE");
+                int decimalDigits = columnsResultSet.getInt("DECIMAL_DIGITS");
+                int nullable = columnsResultSet.getInt("NULLABLE");
 
-            Column column =
-                    convert(columnName, jdbcType, nativeType, nullable, columnSize, decimalDigits);
-            columns.add(column);
+                Column column =
+                        convert(
+                                columnName,
+                                jdbcType,
+                                nativeType,
+                                nullable,
+                                columnSize,
+                                decimalDigits);
+                columns.add(column);
+            }
         }
         return columns;
     }
