@@ -25,13 +25,17 @@ import org.apache.seatunnel.common.exception.CommonErrorCodeDeprecated;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.exception.JdbcConnectorException;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.converter.AbstractJdbcRowConverter;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.DatabaseIdentifier;
+import org.apache.seatunnel.connectors.seatunnel.jdbc.utils.JdbcFieldTypeUtils;
 
 import java.math.BigDecimal;
 import java.sql.PreparedStatement;
+import java.sql.ResultSet;
 import java.sql.SQLException;
+import java.sql.Timestamp;
 import java.time.LocalDate;
 import java.time.LocalDateTime;
 import java.time.LocalTime;
+import java.util.Optional;
 
 public class SqlserverJdbcRowConverter extends AbstractJdbcRowConverter {
 
@@ -40,6 +44,14 @@ public class SqlserverJdbcRowConverter extends AbstractJdbcRowConverter {
         return DatabaseIdentifier.SQLSERVER;
     }
 
+    @Override
+    protected LocalTime readTime(ResultSet rs, int resultSetIndex) throws SQLException {
+        Timestamp sqlTime = JdbcFieldTypeUtils.getTimestamp(rs, resultSetIndex);
+        return Optional.ofNullable(sqlTime)
+                .map(e -> e.toLocalDateTime().toLocalTime())
+                .orElse(null);
+    }
+
     public PreparedStatement toExternal(
             SeaTunnelRowType rowType, SeaTunnelRow row, PreparedStatement statement)
             throws SQLException {
