@@ -96,11 +96,17 @@ public class BufferReducedBatchStatementExecutor
 
     @Override
     public void closeStatements() throws SQLException {
-        if (!buffer.isEmpty()) {
-            executeBatch();
+        try {
+            if (!buffer.isEmpty()) {
+                executeBatch();
+            }
+        } finally {
+            if (!buffer.isEmpty()) {
+                buffer.clear();
+            }
+            upsertExecutor.closeStatements();
+            deleteExecutor.closeStatements();
         }
-        upsertExecutor.closeStatements();
-        deleteExecutor.closeStatements();
     }
 
     private boolean changeFlag(RowKind rowKind) {
