@@ -36,12 +36,14 @@ import static org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.or
 
 public class OracleTypeConverterTest {
 
+    private static final OracleTypeConverter INSTANCE = new OracleTypeConverter();
+
     @Test
     public void testConvertUnsupported() {
         BasicTypeDefine<Object> typeDefine =
                 BasicTypeDefine.builder().name("test").columnType("aaa").dataType("aaa").build();
         try {
-            OracleTypeConverter.INSTANCE.convert(typeDefine);
+            INSTANCE.convert(typeDefine);
             Assertions.fail();
         } catch (SeaTunnelRuntimeException e) {
             // ignore
@@ -51,28 +53,16 @@ public class OracleTypeConverterTest {
     }
 
     @Test
-    public void testConvertInteger() {
-        BasicTypeDefine<Object> typeDefine =
-                BasicTypeDefine.builder()
-                        .name("test")
-                        .columnType("integer")
-                        .dataType("integer")
-                        .build();
-        Column column = OracleTypeConverter.INSTANCE.convert(typeDefine);
-        Assertions.assertEquals(typeDefine.getName(), column.getName());
-        Assertions.assertEquals(new DecimalType(38, 0), column.getDataType());
-        Assertions.assertEquals(typeDefine.getColumnType(), column.getSourceType());
-    }
+    public void testConvertNumberWithoutDecimalTypeNarrowing() {
+        OracleTypeConverter converter = new OracleTypeConverter(false);
 
-    @Test
-    public void testConvertNumber() {
         BasicTypeDefine<Object> typeDefine =
                 BasicTypeDefine.builder()
                         .name("test")
                         .columnType("number")
                         .dataType("number")
                         .build();
-        Column column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        Column column = converter.convert(typeDefine);
 
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(new DecimalType(38, 18), column.getDataType());
@@ -86,7 +76,7 @@ public class OracleTypeConverterTest {
                         .precision(38L)
                         .scale(127)
                         .build();
-        column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        column = converter.convert(typeDefine);
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(new DecimalType(38, 18), column.getDataType());
         Assertions.assertEquals(typeDefine.getColumnType(), column.getSourceType());
@@ -98,7 +88,7 @@ public class OracleTypeConverterTest {
                         .dataType("number")
                         .scale(0)
                         .build();
-        column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        column = converter.convert(typeDefine);
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(new DecimalType(38, 0), column.getDataType());
         Assertions.assertEquals(typeDefine.getColumnType(), column.getSourceType());
@@ -111,9 +101,9 @@ public class OracleTypeConverterTest {
                         .precision(1L)
                         .scale(0)
                         .build();
-        column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        column = converter.convert(typeDefine);
         Assertions.assertEquals(typeDefine.getName(), column.getName());
-        Assertions.assertEquals(BasicType.BOOLEAN_TYPE, column.getDataType());
+        Assertions.assertEquals(new DecimalType(1, 0), column.getDataType());
         Assertions.assertEquals(typeDefine.getColumnType(), column.getSourceType());
 
         typeDefine =
@@ -124,9 +114,9 @@ public class OracleTypeConverterTest {
                         .precision(8L)
                         .scale(0)
                         .build();
-        column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        column = converter.convert(typeDefine);
         Assertions.assertEquals(typeDefine.getName(), column.getName());
-        Assertions.assertEquals(BasicType.INT_TYPE, column.getDataType());
+        Assertions.assertEquals(new DecimalType(8, 0), column.getDataType());
         Assertions.assertEquals(typeDefine.getColumnType(), column.getSourceType());
 
         typeDefine =
@@ -137,9 +127,9 @@ public class OracleTypeConverterTest {
                         .precision(18L)
                         .scale(0)
                         .build();
-        column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        column = converter.convert(typeDefine);
         Assertions.assertEquals(typeDefine.getName(), column.getName());
-        Assertions.assertEquals(BasicType.LONG_TYPE, column.getDataType());
+        Assertions.assertEquals(new DecimalType(18, 0), column.getDataType());
         Assertions.assertEquals(typeDefine.getColumnType(), column.getSourceType());
 
         typeDefine =
@@ -150,7 +140,7 @@ public class OracleTypeConverterTest {
                         .precision(38L)
                         .scale(0)
                         .build();
-        column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        column = converter.convert(typeDefine);
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(new DecimalType(38, 0), column.getDataType());
         Assertions.assertEquals(typeDefine.getColumnType(), column.getSourceType());
@@ -163,7 +153,140 @@ public class OracleTypeConverterTest {
                         .precision(39L)
                         .scale(0)
                         .build();
-        column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        column = converter.convert(typeDefine);
+        Assertions.assertEquals(typeDefine.getName(), column.getName());
+        Assertions.assertEquals(new DecimalType(38, 0), column.getDataType());
+        Assertions.assertEquals(typeDefine.getColumnType(), column.getSourceType());
+    }
+
+    @Test
+    public void testConvertInteger() {
+        BasicTypeDefine<Object> typeDefine =
+                BasicTypeDefine.builder()
+                        .name("test")
+                        .columnType("integer")
+                        .dataType("integer")
+                        .build();
+        Column column = INSTANCE.convert(typeDefine);
+        Assertions.assertEquals(typeDefine.getName(), column.getName());
+        Assertions.assertEquals(new DecimalType(38, 0), column.getDataType());
+        Assertions.assertEquals(typeDefine.getColumnType(), column.getSourceType());
+
+        // generated by int/smallint type in oracle create table sql
+        BasicTypeDefine<Object> numberTypeDefine =
+                BasicTypeDefine.builder()
+                        .name("test")
+                        .columnType("number")
+                        .dataType("number")
+                        .precision(null)
+                        .scale(0)
+                        .build();
+        column = INSTANCE.convert(numberTypeDefine);
+        Assertions.assertEquals(numberTypeDefine.getName(), column.getName());
+        Assertions.assertEquals(new DecimalType(38, 0), column.getDataType());
+        Assertions.assertEquals(numberTypeDefine.getColumnType(), column.getSourceType());
+    }
+
+    @Test
+    public void testConvertNumber() {
+        BasicTypeDefine<Object> typeDefine =
+                BasicTypeDefine.builder()
+                        .name("test")
+                        .columnType("number")
+                        .dataType("number")
+                        .build();
+        Column column = INSTANCE.convert(typeDefine);
+
+        Assertions.assertEquals(typeDefine.getName(), column.getName());
+        Assertions.assertEquals(new DecimalType(38, 18), column.getDataType());
+        Assertions.assertEquals(typeDefine.getColumnType(), column.getSourceType());
+
+        typeDefine =
+                BasicTypeDefine.builder()
+                        .name("test")
+                        .columnType("number(38,127)")
+                        .dataType("number")
+                        .precision(38L)
+                        .scale(127)
+                        .build();
+        column = INSTANCE.convert(typeDefine);
+        Assertions.assertEquals(typeDefine.getName(), column.getName());
+        Assertions.assertEquals(new DecimalType(38, 18), column.getDataType());
+        Assertions.assertEquals(typeDefine.getColumnType(), column.getSourceType());
+
+        typeDefine =
+                BasicTypeDefine.builder()
+                        .name("test")
+                        .columnType("number")
+                        .dataType("number")
+                        .scale(0)
+                        .build();
+        column = INSTANCE.convert(typeDefine);
+        Assertions.assertEquals(typeDefine.getName(), column.getName());
+        Assertions.assertEquals(new DecimalType(38, 0), column.getDataType());
+        Assertions.assertEquals(typeDefine.getColumnType(), column.getSourceType());
+
+        typeDefine =
+                BasicTypeDefine.builder()
+                        .name("test")
+                        .columnType("number(1,0)")
+                        .dataType("number")
+                        .precision(1L)
+                        .scale(0)
+                        .build();
+        column = INSTANCE.convert(typeDefine);
+        Assertions.assertEquals(typeDefine.getName(), column.getName());
+        Assertions.assertEquals(BasicType.BOOLEAN_TYPE, column.getDataType());
+        Assertions.assertEquals(typeDefine.getColumnType(), column.getSourceType());
+
+        typeDefine =
+                BasicTypeDefine.builder()
+                        .name("test")
+                        .columnType("number(8,0)")
+                        .dataType("number")
+                        .precision(8L)
+                        .scale(0)
+                        .build();
+        column = INSTANCE.convert(typeDefine);
+        Assertions.assertEquals(typeDefine.getName(), column.getName());
+        Assertions.assertEquals(BasicType.INT_TYPE, column.getDataType());
+        Assertions.assertEquals(typeDefine.getColumnType(), column.getSourceType());
+
+        typeDefine =
+                BasicTypeDefine.builder()
+                        .name("test")
+                        .columnType("number(18,0)")
+                        .dataType("number")
+                        .precision(18L)
+                        .scale(0)
+                        .build();
+        column = INSTANCE.convert(typeDefine);
+        Assertions.assertEquals(typeDefine.getName(), column.getName());
+        Assertions.assertEquals(BasicType.LONG_TYPE, column.getDataType());
+        Assertions.assertEquals(typeDefine.getColumnType(), column.getSourceType());
+
+        typeDefine =
+                BasicTypeDefine.builder()
+                        .name("test")
+                        .columnType("number(38,0)")
+                        .dataType("number")
+                        .precision(38L)
+                        .scale(0)
+                        .build();
+        column = INSTANCE.convert(typeDefine);
+        Assertions.assertEquals(typeDefine.getName(), column.getName());
+        Assertions.assertEquals(new DecimalType(38, 0), column.getDataType());
+        Assertions.assertEquals(typeDefine.getColumnType(), column.getSourceType());
+
+        typeDefine =
+                BasicTypeDefine.builder()
+                        .name("test")
+                        .columnType("number(39,0)")
+                        .dataType("number")
+                        .precision(39L)
+                        .scale(0)
+                        .build();
+        column = INSTANCE.convert(typeDefine);
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(new DecimalType(38, 0), column.getDataType());
         Assertions.assertEquals(typeDefine.getColumnType(), column.getSourceType());
@@ -177,7 +300,7 @@ public class OracleTypeConverterTest {
                         .columnType("float")
                         .dataType("float")
                         .build();
-        Column column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        Column column = INSTANCE.convert(typeDefine);
 
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(new DecimalType(38, 18), column.getDataType());
@@ -189,7 +312,7 @@ public class OracleTypeConverterTest {
                         .columnType("binary_float")
                         .dataType("binary_float")
                         .build();
-        column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        column = INSTANCE.convert(typeDefine);
 
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(BasicType.FLOAT_TYPE, column.getDataType());
@@ -197,7 +320,7 @@ public class OracleTypeConverterTest {
 
         typeDefine =
                 BasicTypeDefine.builder().name("test").columnType("real").dataType("real").build();
-        column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        column = INSTANCE.convert(typeDefine);
 
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(BasicType.FLOAT_TYPE, column.getDataType());
@@ -212,7 +335,7 @@ public class OracleTypeConverterTest {
                         .columnType("binary_double")
                         .dataType("binary_double")
                         .build();
-        Column column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        Column column = INSTANCE.convert(typeDefine);
 
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(BasicType.DOUBLE_TYPE, column.getDataType());
@@ -228,11 +351,11 @@ public class OracleTypeConverterTest {
                         .dataType("char")
                         .length(1L)
                         .build();
-        Column column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        Column column = INSTANCE.convert(typeDefine);
 
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(BasicType.STRING_TYPE, column.getDataType());
-        Assertions.assertEquals(typeDefine.getLength(), column.getColumnLength());
+        Assertions.assertEquals(typeDefine.getLength() * 4, column.getColumnLength());
         Assertions.assertEquals(typeDefine.getColumnType(), column.getSourceType());
 
         typeDefine =
@@ -242,7 +365,7 @@ public class OracleTypeConverterTest {
                         .dataType("nchar")
                         .length(1L)
                         .build();
-        column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        column = INSTANCE.convert(typeDefine);
 
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(BasicType.STRING_TYPE, column.getDataType());
@@ -256,11 +379,11 @@ public class OracleTypeConverterTest {
                         .dataType("varchar")
                         .length(1L)
                         .build();
-        column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        column = INSTANCE.convert(typeDefine);
 
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(BasicType.STRING_TYPE, column.getDataType());
-        Assertions.assertEquals(typeDefine.getLength(), column.getColumnLength());
+        Assertions.assertEquals(typeDefine.getLength() * 4, column.getColumnLength());
         Assertions.assertEquals(typeDefine.getColumnType(), column.getSourceType());
 
         typeDefine =
@@ -270,11 +393,11 @@ public class OracleTypeConverterTest {
                         .dataType("varchar2")
                         .length(1L)
                         .build();
-        column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        column = INSTANCE.convert(typeDefine);
 
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(BasicType.STRING_TYPE, column.getDataType());
-        Assertions.assertEquals(typeDefine.getLength(), column.getColumnLength());
+        Assertions.assertEquals(typeDefine.getLength() * 4, column.getColumnLength());
         Assertions.assertEquals(typeDefine.getColumnType(), column.getSourceType());
 
         typeDefine =
@@ -284,7 +407,7 @@ public class OracleTypeConverterTest {
                         .dataType("nvarchar2")
                         .length(1L)
                         .build();
-        column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        column = INSTANCE.convert(typeDefine);
 
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(BasicType.STRING_TYPE, column.getDataType());
@@ -297,7 +420,7 @@ public class OracleTypeConverterTest {
                         .columnType("rowid")
                         .dataType("rowid")
                         .build();
-        column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        column = INSTANCE.convert(typeDefine);
 
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(BasicType.STRING_TYPE, column.getDataType());
@@ -311,7 +434,7 @@ public class OracleTypeConverterTest {
                         .dataType("xmltype")
                         .length(1L)
                         .build();
-        column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        column = INSTANCE.convert(typeDefine);
 
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(BasicType.STRING_TYPE, column.getDataType());
@@ -325,7 +448,7 @@ public class OracleTypeConverterTest {
                         .dataType("sys.xmltype")
                         .length(1L)
                         .build();
-        column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        column = INSTANCE.convert(typeDefine);
 
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(BasicType.STRING_TYPE, column.getDataType());
@@ -339,7 +462,7 @@ public class OracleTypeConverterTest {
                         .dataType("long")
                         .length(1L)
                         .build();
-        column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        column = INSTANCE.convert(typeDefine);
 
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(BasicType.STRING_TYPE, column.getDataType());
@@ -348,7 +471,7 @@ public class OracleTypeConverterTest {
 
         typeDefine =
                 BasicTypeDefine.builder().name("test").columnType("clob").dataType("clob").build();
-        column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        column = INSTANCE.convert(typeDefine);
 
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(BasicType.STRING_TYPE, column.getDataType());
@@ -361,7 +484,7 @@ public class OracleTypeConverterTest {
                         .columnType("nclob")
                         .dataType("nclob")
                         .build();
-        column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        column = INSTANCE.convert(typeDefine);
 
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(BasicType.STRING_TYPE, column.getDataType());
@@ -373,7 +496,7 @@ public class OracleTypeConverterTest {
     public void testConvertBytes() {
         BasicTypeDefine<Object> typeDefine =
                 BasicTypeDefine.builder().name("test").columnType("blob").dataType("blob").build();
-        Column column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        Column column = INSTANCE.convert(typeDefine);
 
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(PrimitiveByteArrayType.INSTANCE, column.getDataType());
@@ -382,7 +505,7 @@ public class OracleTypeConverterTest {
 
         typeDefine =
                 BasicTypeDefine.builder().name("test").columnType("raw").dataType("raw").build();
-        column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        column = INSTANCE.convert(typeDefine);
 
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(PrimitiveByteArrayType.INSTANCE, column.getDataType());
@@ -396,7 +519,7 @@ public class OracleTypeConverterTest {
                         .dataType("raw")
                         .length(10L)
                         .build();
-        column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        column = INSTANCE.convert(typeDefine);
 
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(PrimitiveByteArrayType.INSTANCE, column.getDataType());
@@ -409,7 +532,7 @@ public class OracleTypeConverterTest {
                         .columnType("long raw")
                         .dataType("long raw")
                         .build();
-        column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        column = INSTANCE.convert(typeDefine);
 
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(PrimitiveByteArrayType.INSTANCE, column.getDataType());
@@ -421,7 +544,7 @@ public class OracleTypeConverterTest {
     public void testConvertDatetime() {
         BasicTypeDefine<Object> typeDefine =
                 BasicTypeDefine.builder().name("test").columnType("date").dataType("date").build();
-        Column column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        Column column = INSTANCE.convert(typeDefine);
 
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(LocalTimeType.LOCAL_DATE_TIME_TYPE, column.getDataType());
@@ -435,7 +558,7 @@ public class OracleTypeConverterTest {
                         .dataType("timestamp")
                         .scale(6)
                         .build();
-        column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        column = INSTANCE.convert(typeDefine);
 
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(LocalTimeType.LOCAL_DATE_TIME_TYPE, column.getDataType());
@@ -449,7 +572,7 @@ public class OracleTypeConverterTest {
                         .dataType("timestamp with time zone")
                         .scale(6)
                         .build();
-        column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        column = INSTANCE.convert(typeDefine);
 
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(LocalTimeType.LOCAL_DATE_TIME_TYPE, column.getDataType());
@@ -463,7 +586,7 @@ public class OracleTypeConverterTest {
                         .dataType("timestamp with local time zone")
                         .scale(6)
                         .build();
-        column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        column = INSTANCE.convert(typeDefine);
 
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(LocalTimeType.LOCAL_DATE_TIME_TYPE, column.getDataType());
@@ -482,7 +605,7 @@ public class OracleTypeConverterTest {
                         null,
                         null);
         try {
-            OracleTypeConverter.INSTANCE.reconvert(column);
+            INSTANCE.reconvert(column);
             Assertions.fail();
         } catch (SeaTunnelRuntimeException e) {
             // ignore
@@ -496,7 +619,7 @@ public class OracleTypeConverterTest {
         Column column =
                 PhysicalColumn.builder().name("test").dataType(BasicType.BOOLEAN_TYPE).build();
 
-        BasicTypeDefine typeDefine = OracleTypeConverter.INSTANCE.reconvert(column);
+        BasicTypeDefine typeDefine = INSTANCE.reconvert(column);
         Assertions.assertEquals(column.getName(), typeDefine.getName());
         Assertions.assertEquals(
                 String.format("%s(%s)", OracleTypeConverter.ORACLE_NUMBER, 1),
@@ -509,7 +632,7 @@ public class OracleTypeConverterTest {
     public void testReconvertByte() {
         Column column = PhysicalColumn.builder().name("test").dataType(BasicType.BYTE_TYPE).build();
 
-        BasicTypeDefine typeDefine = OracleTypeConverter.INSTANCE.reconvert(column);
+        BasicTypeDefine typeDefine = INSTANCE.reconvert(column);
         Assertions.assertEquals(column.getName(), typeDefine.getName());
         Assertions.assertEquals(OracleTypeConverter.ORACLE_INTEGER, typeDefine.getColumnType());
         Assertions.assertEquals(OracleTypeConverter.ORACLE_INTEGER, typeDefine.getDataType());
@@ -520,7 +643,7 @@ public class OracleTypeConverterTest {
         Column column =
                 PhysicalColumn.builder().name("test").dataType(BasicType.SHORT_TYPE).build();
 
-        BasicTypeDefine typeDefine = OracleTypeConverter.INSTANCE.reconvert(column);
+        BasicTypeDefine typeDefine = INSTANCE.reconvert(column);
         Assertions.assertEquals(column.getName(), typeDefine.getName());
         Assertions.assertEquals(OracleTypeConverter.ORACLE_INTEGER, typeDefine.getColumnType());
         Assertions.assertEquals(OracleTypeConverter.ORACLE_INTEGER, typeDefine.getDataType());
@@ -530,7 +653,7 @@ public class OracleTypeConverterTest {
     public void testReconvertInt() {
         Column column = PhysicalColumn.builder().name("test").dataType(BasicType.INT_TYPE).build();
 
-        BasicTypeDefine typeDefine = OracleTypeConverter.INSTANCE.reconvert(column);
+        BasicTypeDefine typeDefine = INSTANCE.reconvert(column);
         Assertions.assertEquals(column.getName(), typeDefine.getName());
         Assertions.assertEquals(OracleTypeConverter.ORACLE_INTEGER, typeDefine.getColumnType());
         Assertions.assertEquals(OracleTypeConverter.ORACLE_INTEGER, typeDefine.getDataType());
@@ -540,7 +663,7 @@ public class OracleTypeConverterTest {
     public void testReconvertLong() {
         Column column = PhysicalColumn.builder().name("test").dataType(BasicType.LONG_TYPE).build();
 
-        BasicTypeDefine typeDefine = OracleTypeConverter.INSTANCE.reconvert(column);
+        BasicTypeDefine typeDefine = INSTANCE.reconvert(column);
         Assertions.assertEquals(column.getName(), typeDefine.getName());
         Assertions.assertEquals(OracleTypeConverter.ORACLE_INTEGER, typeDefine.getColumnType());
         Assertions.assertEquals(OracleTypeConverter.ORACLE_INTEGER, typeDefine.getDataType());
@@ -551,7 +674,7 @@ public class OracleTypeConverterTest {
         Column column =
                 PhysicalColumn.builder().name("test").dataType(BasicType.FLOAT_TYPE).build();
 
-        BasicTypeDefine typeDefine = OracleTypeConverter.INSTANCE.reconvert(column);
+        BasicTypeDefine typeDefine = INSTANCE.reconvert(column);
         Assertions.assertEquals(column.getName(), typeDefine.getName());
         Assertions.assertEquals(
                 OracleTypeConverter.ORACLE_BINARY_FLOAT, typeDefine.getColumnType());
@@ -563,7 +686,7 @@ public class OracleTypeConverterTest {
         Column column =
                 PhysicalColumn.builder().name("test").dataType(BasicType.DOUBLE_TYPE).build();
 
-        BasicTypeDefine typeDefine = OracleTypeConverter.INSTANCE.reconvert(column);
+        BasicTypeDefine typeDefine = INSTANCE.reconvert(column);
         Assertions.assertEquals(column.getName(), typeDefine.getName());
         Assertions.assertEquals(
                 OracleTypeConverter.ORACLE_BINARY_DOUBLE, typeDefine.getColumnType());
@@ -575,7 +698,7 @@ public class OracleTypeConverterTest {
         Column column =
                 PhysicalColumn.builder().name("test").dataType(new DecimalType(0, 0)).build();
 
-        BasicTypeDefine typeDefine = OracleTypeConverter.INSTANCE.reconvert(column);
+        BasicTypeDefine typeDefine = INSTANCE.reconvert(column);
         Assertions.assertEquals(column.getName(), typeDefine.getName());
         Assertions.assertEquals(
                 String.format(
@@ -588,7 +711,7 @@ public class OracleTypeConverterTest {
 
         column = PhysicalColumn.builder().name("test").dataType(new DecimalType(10, 2)).build();
 
-        typeDefine = OracleTypeConverter.INSTANCE.reconvert(column);
+        typeDefine = INSTANCE.reconvert(column);
         Assertions.assertEquals(column.getName(), typeDefine.getName());
         Assertions.assertEquals(
                 String.format("%s(%s,%s)", OracleTypeConverter.ORACLE_NUMBER, 10, 2),
@@ -605,7 +728,7 @@ public class OracleTypeConverterTest {
                         .columnLength(null)
                         .build();
 
-        BasicTypeDefine typeDefine = OracleTypeConverter.INSTANCE.reconvert(column);
+        BasicTypeDefine typeDefine = INSTANCE.reconvert(column);
         Assertions.assertEquals(column.getName(), typeDefine.getName());
         Assertions.assertEquals(OracleTypeConverter.ORACLE_BLOB, typeDefine.getColumnType());
         Assertions.assertEquals(OracleTypeConverter.ORACLE_BLOB, typeDefine.getDataType());
@@ -617,7 +740,7 @@ public class OracleTypeConverterTest {
                         .columnLength(2000L)
                         .build();
 
-        typeDefine = OracleTypeConverter.INSTANCE.reconvert(column);
+        typeDefine = INSTANCE.reconvert(column);
         Assertions.assertEquals(column.getName(), typeDefine.getName());
         Assertions.assertEquals(
                 String.format("%s(%s)", OracleTypeConverter.ORACLE_RAW, column.getColumnLength()),
@@ -631,7 +754,7 @@ public class OracleTypeConverterTest {
                         .columnLength(BYTES_2GB)
                         .build();
 
-        typeDefine = OracleTypeConverter.INSTANCE.reconvert(column);
+        typeDefine = INSTANCE.reconvert(column);
         Assertions.assertEquals(column.getName(), typeDefine.getName());
         Assertions.assertEquals(OracleTypeConverter.ORACLE_BLOB, typeDefine.getColumnType());
         Assertions.assertEquals(OracleTypeConverter.ORACLE_BLOB, typeDefine.getDataType());
@@ -643,7 +766,7 @@ public class OracleTypeConverterTest {
                         .columnLength(BYTES_2GB + 1)
                         .build();
 
-        typeDefine = OracleTypeConverter.INSTANCE.reconvert(column);
+        typeDefine = INSTANCE.reconvert(column);
         Assertions.assertEquals(column.getName(), typeDefine.getName());
         Assertions.assertEquals(OracleTypeConverter.ORACLE_BLOB, typeDefine.getColumnType());
         Assertions.assertEquals(OracleTypeConverter.ORACLE_BLOB, typeDefine.getDataType());
@@ -658,7 +781,7 @@ public class OracleTypeConverterTest {
                         .columnLength(null)
                         .build();
 
-        BasicTypeDefine typeDefine = OracleTypeConverter.INSTANCE.reconvert(column);
+        BasicTypeDefine typeDefine = INSTANCE.reconvert(column);
         Assertions.assertEquals(column.getName(), typeDefine.getName());
         Assertions.assertEquals("VARCHAR2(4000)", typeDefine.getColumnType());
         Assertions.assertEquals(OracleTypeConverter.ORACLE_VARCHAR2, typeDefine.getDataType());
@@ -670,7 +793,7 @@ public class OracleTypeConverterTest {
                         .columnLength(2000L)
                         .build();
 
-        typeDefine = OracleTypeConverter.INSTANCE.reconvert(column);
+        typeDefine = INSTANCE.reconvert(column);
         Assertions.assertEquals(column.getName(), typeDefine.getName());
         Assertions.assertEquals(
                 String.format(
@@ -685,7 +808,7 @@ public class OracleTypeConverterTest {
                         .columnLength(4000L)
                         .build();
 
-        typeDefine = OracleTypeConverter.INSTANCE.reconvert(column);
+        typeDefine = INSTANCE.reconvert(column);
         Assertions.assertEquals(column.getName(), typeDefine.getName());
         Assertions.assertEquals(
                 String.format(
@@ -700,7 +823,7 @@ public class OracleTypeConverterTest {
                         .columnLength(40001L)
                         .build();
 
-        typeDefine = OracleTypeConverter.INSTANCE.reconvert(column);
+        typeDefine = INSTANCE.reconvert(column);
         Assertions.assertEquals(column.getName(), typeDefine.getName());
         Assertions.assertEquals(OracleTypeConverter.ORACLE_CLOB, typeDefine.getColumnType());
         Assertions.assertEquals(OracleTypeConverter.ORACLE_CLOB, typeDefine.getDataType());
@@ -714,7 +837,7 @@ public class OracleTypeConverterTest {
                         .dataType(LocalTimeType.LOCAL_DATE_TYPE)
                         .build();
 
-        BasicTypeDefine typeDefine = OracleTypeConverter.INSTANCE.reconvert(column);
+        BasicTypeDefine typeDefine = INSTANCE.reconvert(column);
         Assertions.assertEquals(column.getName(), typeDefine.getName());
         Assertions.assertEquals(OracleTypeConverter.ORACLE_DATE, typeDefine.getColumnType());
         Assertions.assertEquals(OracleTypeConverter.ORACLE_DATE, typeDefine.getDataType());
@@ -728,7 +851,7 @@ public class OracleTypeConverterTest {
                         .dataType(LocalTimeType.LOCAL_DATE_TIME_TYPE)
                         .build();
 
-        BasicTypeDefine typeDefine = OracleTypeConverter.INSTANCE.reconvert(column);
+        BasicTypeDefine typeDefine = INSTANCE.reconvert(column);
         Assertions.assertEquals(column.getName(), typeDefine.getName());
         Assertions.assertEquals(
                 OracleTypeConverter.ORACLE_TIMESTAMP_WITH_LOCAL_TIME_ZONE,
@@ -744,7 +867,7 @@ public class OracleTypeConverterTest {
                         .scale(3)
                         .build();
 
-        typeDefine = OracleTypeConverter.INSTANCE.reconvert(column);
+        typeDefine = INSTANCE.reconvert(column);
         Assertions.assertEquals(column.getName(), typeDefine.getName());
         Assertions.assertEquals(
                 String.format("TIMESTAMP(%s) WITH LOCAL TIME ZONE", column.getScale()),
@@ -765,7 +888,7 @@ public class OracleTypeConverterTest {
                         .precision(38L)
                         .scale(-1)
                         .build();
-        Column column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        Column column = INSTANCE.convert(typeDefine);
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(new DecimalType(38, 0), column.getDataType());
         Assertions.assertEquals(typeDefine.getColumnType(), column.getSourceType());
@@ -778,7 +901,7 @@ public class OracleTypeConverterTest {
                         .precision(5L)
                         .scale(-2)
                         .build();
-        column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        column = INSTANCE.convert(typeDefine);
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(BasicType.INT_TYPE, column.getDataType());
         Assertions.assertEquals(typeDefine.getColumnType(), column.getSourceType());
@@ -791,7 +914,7 @@ public class OracleTypeConverterTest {
                         .precision(9L)
                         .scale(-2)
                         .build();
-        column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        column = INSTANCE.convert(typeDefine);
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(BasicType.LONG_TYPE, column.getDataType());
         Assertions.assertEquals(typeDefine.getColumnType(), column.getSourceType());
@@ -804,7 +927,7 @@ public class OracleTypeConverterTest {
                         .precision(14L)
                         .scale(-11)
                         .build();
-        column = OracleTypeConverter.INSTANCE.convert(typeDefine);
+        column = INSTANCE.convert(typeDefine);
         Assertions.assertEquals(typeDefine.getName(), column.getName());
         Assertions.assertEquals(new DecimalType(25, 0), column.getDataType());
         Assertions.assertEquals(typeDefine.getColumnType(), column.getSourceType());
