@@ -188,15 +188,21 @@ public class KafkaSinkWriter implements SinkWriter<SeaTunnelRow, KafkaCommitInfo
                     getPartitionKeyFields(pluginConfig, seaTunnelRowType),
                     seaTunnelRowType,
                     messageFormat,
-                    delimiter);
+                    delimiter,
+                    pluginConfig);
         }
         if (pluginConfig.get(PARTITION) != null) {
             return DefaultSeaTunnelRowSerializer.create(
-                    topic, pluginConfig.get(PARTITION), seaTunnelRowType, messageFormat, delimiter);
+                    topic,
+                    pluginConfig.get(PARTITION),
+                    seaTunnelRowType,
+                    messageFormat,
+                    delimiter,
+                    pluginConfig);
         }
         // By default, all partitions are sent randomly
         return DefaultSeaTunnelRowSerializer.create(
-                topic, Arrays.asList(), seaTunnelRowType, messageFormat, delimiter);
+                topic, Arrays.asList(), seaTunnelRowType, messageFormat, delimiter, pluginConfig);
     }
 
     private KafkaSemantics getKafkaSemantics(ReadonlyConfig pluginConfig) {
