@@ -34,6 +34,7 @@ import org.apache.seatunnel.api.table.type.SeaTunnelDataType;
 import org.apache.seatunnel.api.table.type.SeaTunnelRow;
 import org.apache.seatunnel.api.table.type.SqlType;
 import org.apache.seatunnel.api.table.type.VectorType;
+import org.apache.seatunnel.common.utils.BufferUtils;
 import org.apache.seatunnel.common.utils.JsonUtils;
 import org.apache.seatunnel.connectors.seatunnel.milvus.catalog.MilvusOptions;
 import org.apache.seatunnel.connectors.seatunnel.milvus.config.MilvusSourceConfig;
@@ -44,6 +45,8 @@ import org.apache.commons.collections4.CollectionUtils;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.hadoop.util.Lists;
 
+import com.google.gson.Gson;
+import com.google.gson.JsonParser;
 import com.google.protobuf.ProtocolStringList;
 import io.milvus.client.MilvusServiceClient;
 import io.milvus.common.utils.JacksonUtils;
@@ -62,6 +65,7 @@ import io.milvus.param.collection.DescribeCollectionParam;
 import io.milvus.param.collection.ShowCollectionsParam;
 import io.milvus.param.index.DescribeIndexParam;
 
+import java.nio.ByteBuffer;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashMap;
@@ -73,44 +77,55 @@ public class MilvusConvertUtils {
 
     private static final String CATALOG_NAME = "Milvus";
 
+    private static final Gson gson = new Gson();
+
     public static Map<TablePath, CatalogTable> getSourceTables(ReadonlyConfig config) {
-        MilvusServiceClient client =
-                new MilvusServiceClient(
-                        ConnectParam.newBuilder()
-                                .withUri(config.get(MilvusSourceConfig.URL))
-                                .withToken(config.get(MilvusSourceConfig.TOKEN))
-                                .build());
-
-        String database = config.get(MilvusSourceConfig.DATABASE);
-        List<String> collectionList = new ArrayList<>();
-        if (StringUtils.isNotEmpty(config.get(MilvusSourceConfig.COLLECTION))) {
-            collectionList.add(config.get(MilvusSourceConfig.COLLECTION));
-        } else {
-            R<ShowCollectionsResponse> response =
-                    client.showCollections(
-                            ShowCollectionsParam.newBuilder()
-                                    .withDatabaseName(database)
-                                    .withShowType(ShowType.All)
+        MilvusServiceClient client = null;
+        try {
+            client =
+                    new MilvusServiceClient(
+                            ConnectParam.newBuilder()
+                                    .withUri(config.get(MilvusSourceConfig.URL))
+                                    .withToken(config.get(MilvusSourceConfig.TOKEN))
                                     .build());
-            if (response.getStatus() != R.Status.Success.getCode()) {
-                throw new MilvusConnectorException(
-                        MilvusConnectionErrorCode.SHOW_COLLECTIONS_ERROR);
+
+            String database = config.get(MilvusSourceConfig.DATABASE);
+            List<String> collectionList = new ArrayList<>();
+            if (StringUtils.isNotEmpty(config.get(MilvusSourceConfig.COLLECTION))) {
+                collectionList.add(config.get(MilvusSourceConfig.COLLECTION));
+            } else {
+                R<ShowCollectionsResponse> response =
+                        client.showCollections(
+                                ShowCollectionsParam.newBuilder()
+                                        .withDatabaseName(database)
+                                        .withShowType(ShowType.All)
+                                        .build());
+                if (response.getStatus() != R.Status.Success.getCode()) {
+                    throw new MilvusConnectorException(
+                            MilvusConnectionErrorCode.SHOW_COLLECTIONS_ERROR);
+                }
+
+                ProtocolStringList collections = response.getData().getCollectionNamesList();
+                if (CollectionUtils.isEmpty(collections)) {
+                    throw new MilvusConnectorException(
+                            MilvusConnectionErrorCode.DATABASE_NO_COLLECTIONS, database);
+                }
+                collectionList.addAll(collections);
             }
 
-            ProtocolStringList collections = response.getData().getCollectionNamesList();
-            if (CollectionUtils.isEmpty(collections)) {
-                throw new MilvusConnectorException(
-                        MilvusConnectionErrorCode.DATABASE_NO_COLLECTIONS, database);
+            Map<TablePath, CatalogTable> map = new HashMap<>();
+            for (String collection : collectionList) {
+                CatalogTable catalogTable = getCatalogTable(client, database, collection);
+                map.put(TablePath.of(database, collection), catalogTable);
+            }
+            return map;
+        } catch (Exception e) {
+            throw new CatalogException(e.getMessage(), e);
+        } finally {
+            if (client != null) {
+                client.close();
             }
-            collectionList.addAll(collections);
         }
-
-        Map<TablePath, CatalogTable> map = new HashMap<>();
-        for (String collection : collectionList) {
-            CatalogTable catalogTable = getCatalogTable(client, database, collection);
-            map.put(TablePath.of(database, collection), catalogTable);
-        }
-        return map;
     }
 
     public static CatalogTable getCatalogTable(
@@ -315,11 +330,16 @@ public class MilvusConvertUtils {
             case DATE:
                 return value.toString();
             case FLOAT_VECTOR:
-                List<Float> vector = new ArrayList<>();
-                for (Object o : (Object[]) value) {
-                    vector.add(Float.parseFloat(o.toString()));
-                }
-                return vector;
+                ByteBuffer floatVectorBuffer = (ByteBuffer) value;
+                Float[] floats = BufferUtils.toFloatArray(floatVectorBuffer);
+                return Arrays.stream(floats).collect(Collectors.toList());
+            case BINARY_VECTOR:
+            case BFLOAT16_VECTOR:
+            case FLOAT16_VECTOR:
+                ByteBuffer vector = (ByteBuffer) value;
+                return gson.toJsonTree(vector.array());
+            case SPARSE_FLOAT_VECTOR:
+                return JsonParser.parseString(JacksonUtils.toJsonString(value)).getAsJsonObject();
             case FLOAT:
                 return Float.parseFloat(value.toString());
             case BOOLEAN:
