@@ -25,6 +25,11 @@ import org.apache.seatunnel.api.configuration.Options;
 import org.apache.seatunnel.api.configuration.ReadonlyConfig;
 import org.apache.seatunnel.api.sink.SeaTunnelSink;
 import org.apache.seatunnel.api.source.SeaTunnelSource;
+import org.apache.seatunnel.common.exception.CommonError;
+import org.apache.seatunnel.common.utils.SeaTunnelException;
+import org.apache.seatunnel.connectors.seatunnel.paimon.catalog.PaimonCatalogEnum;
+
+import org.apache.commons.lang3.StringUtils;
 
 import lombok.Getter;
 
@@ -35,7 +40,6 @@ import java.util.List;
 import java.util.Map;
 
 import static java.util.stream.Collectors.toList;
-import static org.apache.seatunnel.shade.com.google.common.base.Preconditions.checkNotNull;
 
 /**
  * Utility class to store configuration options, used by {@link SeaTunnelSource} and {@link
@@ -44,17 +48,31 @@ import static org.apache.seatunnel.shade.com.google.common.base.Preconditions.ch
 @Getter
 public class PaimonConfig implements Serializable {
 
+    public static final String CONNECTOR_IDENTITY = "Paimon";
+
     public static final Option<String> WAREHOUSE =
             Options.key("warehouse")
                     .stringType()
                     .noDefaultValue()
                     .withDescription("The warehouse path of paimon");
 
+    public static final Option<PaimonCatalogEnum> CATALOG_TYPE =
+            Options.key("catalog_type")
+                    .enumType(PaimonCatalogEnum.class)
+                    .defaultValue(PaimonCatalogEnum.FILESYSTEM)
+                    .withDescription("The type of paimon catalog");
+
+    public static final Option<String> CATALOG_URI =
+            Options.key("catalog_uri")
+                    .stringType()
+                    .noDefaultValue()
+                    .withDescription("The uri of paimon with hive catalog");
+
     public static final Option<String> CATALOG_NAME =
             Options.key("catalog_name")
                     .stringType()
                     .defaultValue("paimon")
-                    .withDescription(" the iceberg catalog name");
+                    .withDescription(" the paimon catalog name");
 
     public static final Option<String> DATABASE =
             Options.key("database")
@@ -68,12 +86,6 @@ public class PaimonConfig implements Serializable {
                     .noDefaultValue()
                     .withDescription("The table you intend to access");
 
-    public static final Option<List<String>> READ_COLUMNS =
-            Options.key("read_columns")
-                    .listType()
-                    .noDefaultValue()
-                    .withDescription("The read columns of the flink table store");
-
     @Deprecated
     public static final Option<String> HDFS_SITE_PATH =
             Options.key("hdfs_site_path")
@@ -95,6 +107,8 @@ public class PaimonConfig implements Serializable {
                             "The specified loading path for the 'core-site.xml', 'hdfs-site.xml', 'hive-site.xml' files");
 
     protected String catalogName;
+    protected PaimonCatalogEnum catalogType;
+    protected String catalogUri;
     protected String warehouse;
     protected String namespace;
     protected String table;
@@ -103,18 +117,27 @@ public class PaimonConfig implements Serializable {
     protected String hadoopConfPath;
 
     public PaimonConfig(ReadonlyConfig readonlyConfig) {
-        this.catalogName = checkArgumentNotNull(readonlyConfig.get(CATALOG_NAME));
-        this.warehouse = checkArgumentNotNull(readonlyConfig.get(WAREHOUSE));
-        this.namespace = checkArgumentNotNull(readonlyConfig.get(DATABASE));
-        this.table = checkArgumentNotNull(readonlyConfig.get(TABLE));
+        this.catalogName =
+                checkArgumentNotBlank(readonlyConfig.get(CATALOG_NAME), CATALOG_NAME.key());
+        this.warehouse = checkArgumentNotBlank(readonlyConfig.get(WAREHOUSE), WAREHOUSE.key());
+        this.namespace = checkArgumentNotBlank(readonlyConfig.get(DATABASE), DATABASE.key());
+        this.table = checkArgumentNotBlank(readonlyConfig.get(TABLE), TABLE.key());
         this.hdfsSitePath = readonlyConfig.get(HDFS_SITE_PATH);
         this.hadoopConfProps = readonlyConfig.get(HADOOP_CONF);
         this.hadoopConfPath = readonlyConfig.get(HADOOP_CONF_PATH);
+        this.catalogType = readonlyConfig.get(CATALOG_TYPE);
+        if (PaimonCatalogEnum.HIVE.getType().equals(catalogType.getType())) {
+            this.catalogUri =
+                    checkArgumentNotBlank(readonlyConfig.get(CATALOG_URI), CATALOG_URI.key());
+        }
     }
 
-    protected <T> T checkArgumentNotNull(T argument) {
-        checkNotNull(argument);
-        return argument;
+    protected String checkArgumentNotBlank(String propValue, String propKey) {
+        if (StringUtils.isBlank(propValue)) {
+            throw new SeaTunnelException(
+                    CommonError.convertToConnectorPropsBlankError("Paimon", propKey));
+        }
+        return propValue;
     }
 
     @VisibleForTesting
