@@ -27,6 +27,7 @@ import org.apache.seatunnel.connectors.seatunnel.paimon.config.PaimonHadoopConfi
 import org.apache.seatunnel.connectors.seatunnel.paimon.exception.PaimonConnectorErrorCode;
 import org.apache.seatunnel.connectors.seatunnel.paimon.exception.PaimonConnectorException;
 import org.apache.seatunnel.connectors.seatunnel.paimon.security.PaimonSecurityContext;
+import org.apache.seatunnel.connectors.seatunnel.paimon.sink.bucket.PaimonBucketAssigner;
 import org.apache.seatunnel.connectors.seatunnel.paimon.sink.commit.PaimonCommitInfo;
 import org.apache.seatunnel.connectors.seatunnel.paimon.sink.state.PaimonSinkState;
 import org.apache.seatunnel.connectors.seatunnel.paimon.utils.JobContextUtil;
@@ -34,6 +35,7 @@ import org.apache.seatunnel.connectors.seatunnel.paimon.utils.RowConverter;
 
 import org.apache.paimon.data.InternalRow;
 import org.apache.paimon.schema.TableSchema;
+import org.apache.paimon.table.BucketMode;
 import org.apache.paimon.table.FileStoreTable;
 import org.apache.paimon.table.Table;
 import org.apache.paimon.table.sink.BatchTableCommit;
@@ -67,8 +69,6 @@ public class PaimonSinkWriter
 
     private final TableWrite tableWrite;
 
-    private long checkpointId = 0;
-
     private List<CommitMessage> committables = new ArrayList<>();
 
     private final Table table;
@@ -79,7 +79,11 @@ public class PaimonSinkWriter
 
     private final JobContext jobContext;
 
-    private TableSchema tableSchema;
+    private final TableSchema tableSchema;
+
+    private PaimonBucketAssigner bucketAssigner;
+
+    private final boolean dynamicBucket;
 
     public PaimonSinkWriter(
             Context context,
@@ -97,6 +101,20 @@ public class PaimonSinkWriter
         this.context = context;
         this.jobContext = jobContext;
         this.tableSchema = ((FileStoreTable) table).schema();
+        BucketMode bucketMode = ((FileStoreTable) table).bucketMode();
+        this.dynamicBucket =
+                BucketMode.DYNAMIC == bucketMode || BucketMode.GLOBAL_DYNAMIC == bucketMode;
+        int bucket = ((FileStoreTable) table).coreOptions().bucket();
+        if (bucket == -1 && BucketMode.UNAWARE == bucketMode) {
+            log.warn("Append only table currently do not support dynamic bucket");
+        }
+        if (dynamicBucket) {
+            this.bucketAssigner =
+                    new PaimonBucketAssigner(
+                            table,
+                            this.context.getNumberOfParallelSubtasks(),
+                            this.context.getIndexOfSubtask());
+        }
         PaimonSecurityContext.shouldEnableKerberos(paimonHadoopConfiguration);
     }
 
@@ -112,7 +130,6 @@ public class PaimonSinkWriter
             return;
         }
         this.commitUser = states.get(0).getCommitUser();
-        this.checkpointId = states.get(0).getCheckpointId();
         try (TableCommit tableCommit = tableWriteBuilder.newCommit()) {
             List<CommitMessage> commitables =
                     states.stream()
@@ -139,7 +156,12 @@ public class PaimonSinkWriter
         try {
             PaimonSecurityContext.runSecured(
                     () -> {
-                        tableWrite.write(rowData);
+                        if (dynamicBucket) {
+                            int bucket = bucketAssigner.assign(rowData);
+                            tableWrite.write(rowData, bucket);
+                        } else {
+                            tableWrite.write(rowData);
+                        }
                         return null;
                     });
         } catch (Exception e) {
@@ -172,7 +194,6 @@ public class PaimonSinkWriter
 
     @Override
     public List<PaimonSinkState> snapshotState(long checkpointId) throws IOException {
-        this.checkpointId = checkpointId;
         PaimonSinkState paimonSinkState =
                 new PaimonSinkState(new ArrayList<>(committables), commitUser, checkpointId);
         committables.clear();
@@ -184,13 +205,17 @@ public class PaimonSinkWriter
 
     @Override
     public void close() throws IOException {
-        if (Objects.nonNull(tableWrite)) {
-            try {
-                tableWrite.close();
-            } catch (Exception e) {
-                log.error("Failed to close table writer in paimon sink writer.", e);
-                throw new SeaTunnelException(e);
+        try {
+            if (Objects.nonNull(tableWrite)) {
+                try {
+                    tableWrite.close();
+                } catch (Exception e) {
+                    log.error("Failed to close table writer in paimon sink writer.", e);
+                    throw new SeaTunnelException(e);
+                }
             }
+        } finally {
+            committables.clear();
         }
     }
 }
