@@ -56,14 +56,13 @@ import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.ResultSetMetaData;
 import java.sql.SQLException;
+import java.sql.Statement;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
-import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Optional;
-import java.util.Set;
 import java.util.stream.IntStream;
 
 import static org.apache.seatunnel.shade.com.google.common.base.Preconditions.checkArgument;
@@ -79,15 +78,10 @@ public class StarRocksCatalog implements Catalog {
     protected String defaultUrl;
     private final JdbcUrlUtil.UrlInfo urlInfo;
     private final String template;
+    private Connection conn;
 
-    private static final Set<String> SYS_DATABASES = new HashSet<>();
     private static final Logger LOG = LoggerFactory.getLogger(StarRocksCatalog.class);
 
-    static {
-        SYS_DATABASES.add("information_schema");
-        SYS_DATABASES.add("_statistics_");
-    }
-
     public StarRocksCatalog(
             String catalogName, String username, String pwd, String defaultUrl, String template) {
 
@@ -107,18 +101,12 @@ public class StarRocksCatalog implements Catalog {
 
     @Override
     public List<String> listDatabases() throws CatalogException {
-        try (Connection conn = DriverManager.getConnection(defaultUrl, username, pwd)) {
-
-            PreparedStatement ps = conn.prepareStatement("SHOW DATABASES;");
-
+        try (PreparedStatement ps = conn.prepareStatement("SHOW DATABASES;");
+                ResultSet rs = ps.executeQuery()) {
             List<String> databases = new ArrayList<>();
-            ResultSet rs = ps.executeQuery();
 
             while (rs.next()) {
-                String databaseName = rs.getString(1);
-                if (!SYS_DATABASES.contains(databaseName)) {
-                    databases.add(rs.getString(1));
-                }
+                databases.add(rs.getString(1));
             }
 
             return databases;
@@ -135,21 +123,19 @@ public class StarRocksCatalog implements Catalog {
             throw new DatabaseNotExistException(this.catalogName, databaseName);
         }
 
-        try (Connection conn =
-                DriverManager.getConnection(
-                        urlInfo.getUrlWithDatabase(databaseName), username, pwd)) {
-            PreparedStatement ps = conn.prepareStatement("SHOW TABLES;");
-
-            ResultSet rs = ps.executeQuery();
-
-            List<String> tables = new ArrayList<>();
-
-            while (rs.next()) {
-                tables.add(rs.getString(1));
+        try (PreparedStatement ps =
+                conn.prepareStatement(
+                        "SELECT TABLE_NAME FROM information_schema.tables "
+                                + "WHERE TABLE_SCHEMA = ? ORDER BY TABLE_NAME")) {
+            ps.setString(1, databaseName);
+            try (ResultSet rs = ps.executeQuery()) {
+                List<String> tables = new ArrayList<>();
+                while (rs.next()) {
+                    tables.add(rs.getString(1));
+                }
+                return tables;
             }
-
-            return tables;
-        } catch (Exception e) {
+        } catch (SQLException e) {
             throw new CatalogException(
                     String.format("Failed listing database in catalog %s", catalogName), e);
         }
@@ -162,8 +148,7 @@ public class StarRocksCatalog implements Catalog {
             throw new TableNotExistException(catalogName, tablePath);
         }
 
-        String dbUrl = urlInfo.getUrlWithDatabase(tablePath.getDatabaseName());
-        try (Connection conn = DriverManager.getConnection(dbUrl, username, pwd)) {
+        try {
             Optional<PrimaryKey> primaryKey =
                     getPrimaryKey(tablePath.getDatabaseName(), tablePath.getTableName());
 
@@ -227,7 +212,7 @@ public class StarRocksCatalog implements Catalog {
     @Override
     public void dropTable(TablePath tablePath, boolean ignoreIfNotExists)
             throws TableNotExistException, CatalogException {
-        try (Connection conn = DriverManager.getConnection(defaultUrl, username, pwd)) {
+        try {
             conn.createStatement()
                     .execute(StarRocksSaveModeUtil.getDropTableSql(tablePath, ignoreIfNotExists));
         } catch (Exception e) {
@@ -238,7 +223,7 @@ public class StarRocksCatalog implements Catalog {
 
     public void truncateTable(TablePath tablePath, boolean ignoreIfNotExists)
             throws TableNotExistException, CatalogException {
-        try (Connection conn = DriverManager.getConnection(defaultUrl, username, pwd)) {
+        try {
             if (ignoreIfNotExists) {
                 conn.createStatement()
                         .execute(StarRocksSaveModeUtil.getTruncateTableSql(tablePath));
@@ -251,17 +236,17 @@ public class StarRocksCatalog implements Catalog {
     }
 
     public void executeSql(TablePath tablePath, String sql) {
-        try (Connection connection = DriverManager.getConnection(defaultUrl, username, pwd)) {
-            connection.createStatement().execute(sql);
+        try {
+            conn.createStatement().execute(sql);
         } catch (Exception e) {
             throw new CatalogException(String.format("Failed EXECUTE SQL in catalog %s", sql), e);
         }
     }
 
     public boolean isExistsData(TablePath tablePath) {
-        try (Connection connection = DriverManager.getConnection(defaultUrl, username, pwd)) {
-            String sql = String.format("select * from %s limit 1", tablePath.getFullName());
-            ResultSet resultSet = connection.createStatement().executeQuery(sql);
+        String sql = String.format("select * from %s limit 1", tablePath.getFullName());
+        try (Statement statement = conn.createStatement();
+                ResultSet resultSet = statement.executeQuery(sql)) {
             if (resultSet == null) {
                 return false;
             }
@@ -275,7 +260,7 @@ public class StarRocksCatalog implements Catalog {
     @Override
     public void createDatabase(TablePath tablePath, boolean ignoreIfExists)
             throws DatabaseAlreadyExistException, CatalogException {
-        try (Connection conn = DriverManager.getConnection(defaultUrl, username, pwd)) {
+        try {
             conn.createStatement()
                     .execute(
                             StarRocksSaveModeUtil.getCreateDatabaseSql(
@@ -289,7 +274,7 @@ public class StarRocksCatalog implements Catalog {
     @Override
     public void dropDatabase(TablePath tablePath, boolean ignoreIfNotExists)
             throws DatabaseNotExistException, CatalogException {
-        try (Connection conn = DriverManager.getConnection(defaultUrl, username, pwd)) {
+        try {
             conn.createStatement()
                     .execute(
                             StarRocksSaveModeUtil.getDropDatabaseSql(
@@ -381,7 +366,7 @@ public class StarRocksCatalog implements Catalog {
 
     public void createTable(String sql)
             throws TableAlreadyExistException, DatabaseNotExistException, CatalogException {
-        try (Connection conn = DriverManager.getConnection(defaultUrl, username, pwd)) {
+        try {
             log.info("create table sql is :{}", sql);
             conn.createStatement().execute(sql);
         } catch (Exception e) {
@@ -431,7 +416,8 @@ public class StarRocksCatalog implements Catalog {
 
     @Override
     public void open() throws CatalogException {
-        try (Connection conn = DriverManager.getConnection(defaultUrl, username, pwd)) {
+        try {
+            conn = DriverManager.getConnection(defaultUrl, username, pwd);
             // test connection, fail early if we cannot connect to database
             conn.getCatalog();
         } catch (SQLException e) {
@@ -445,6 +431,11 @@ public class StarRocksCatalog implements Catalog {
     @Override
     public void close() throws CatalogException {
         LOG.info("Catalog {} closing", catalogName);
+        try {
+            conn.close();
+        } catch (SQLException e) {
+            throw new CatalogException("close doris catalog failed", e);
+        }
     }
 
     @Override
@@ -455,13 +446,12 @@ public class StarRocksCatalog implements Catalog {
     protected Optional<PrimaryKey> getPrimaryKey(String schema, String table) throws SQLException {
 
         List<String> pkFields = new ArrayList<>();
-        try (Connection conn = DriverManager.getConnection(defaultUrl, username, pwd)) {
-            ResultSet rs =
-                    conn.createStatement()
-                            .executeQuery(
-                                    String.format(
-                                            "SELECT COLUMN_NAME FROM information_schema.columns where TABLE_SCHEMA = '%s' AND TABLE_NAME = '%s' AND COLUMN_KEY = 'PRI' ORDER BY ORDINAL_POSITION",
-                                            schema, table));
+        try (ResultSet rs =
+                conn.createStatement()
+                        .executeQuery(
+                                String.format(
+                                        "SELECT COLUMN_NAME FROM information_schema.columns where TABLE_SCHEMA = '%s' AND TABLE_NAME = '%s' AND COLUMN_KEY = 'PRI' ORDER BY ORDINAL_POSITION",
+                                        schema, table))) {
             while (rs.next()) {
                 String columnName = rs.getString("COLUMN_NAME");
                 pkFields.add(columnName);
@@ -484,11 +474,19 @@ public class StarRocksCatalog implements Catalog {
 
     @Override
     public boolean tableExists(TablePath tablePath) throws CatalogException {
-        try {
-            return databaseExists(tablePath.getDatabaseName())
-                    && listTables(tablePath.getDatabaseName()).contains(tablePath.getTableName());
-        } catch (DatabaseNotExistException e) {
-            return false;
+        try (PreparedStatement ps =
+                conn.prepareStatement(
+                        "SELECT TABLE_NAME FROM information_schema.tables "
+                                + "WHERE TABLE_SCHEMA = ? AND TABLE_NAME = ? "
+                                + "ORDER BY TABLE_NAME")) {
+            ps.setString(1, tablePath.getDatabaseName());
+            ps.setString(2, tablePath.getTableName());
+            try (ResultSet rs = ps.executeQuery()) {
+                return rs.next();
+            }
+        } catch (SQLException e) {
+            throw new CatalogException(
+                    String.format("check table [%s] exists failed", tablePath.getFullName()), e);
         }
     }
 
