@@ -26,10 +26,15 @@ import org.apache.seatunnel.api.configuration.util.ConfigValidator;
 import org.apache.seatunnel.api.sink.SaveModeExecuteWrapper;
 import org.apache.seatunnel.api.sink.SaveModeHandler;
 import org.apache.seatunnel.api.sink.SeaTunnelSink;
+import org.apache.seatunnel.api.sink.SupportMultiTableSink;
 import org.apache.seatunnel.api.sink.SupportSaveMode;
+import org.apache.seatunnel.api.table.catalog.CatalogTable;
+import org.apache.seatunnel.api.table.catalog.TableIdentifier;
 import org.apache.seatunnel.api.table.factory.Factory;
+import org.apache.seatunnel.api.table.factory.FactoryUtil;
 import org.apache.seatunnel.api.table.factory.TableSinkFactory;
 import org.apache.seatunnel.api.table.factory.TableSinkFactoryContext;
+import org.apache.seatunnel.api.table.type.SeaTunnelRow;
 import org.apache.seatunnel.api.table.type.SeaTunnelRowType;
 import org.apache.seatunnel.common.exception.SeaTunnelRuntimeException;
 import org.apache.seatunnel.core.starter.enums.PluginType;
@@ -41,10 +46,13 @@ import org.apache.seatunnel.plugin.discovery.seatunnel.SeaTunnelSinkPluginDiscov
 import org.apache.seatunnel.translation.flink.sink.FlinkSink;
 
 import org.apache.flink.streaming.api.datastream.DataStreamSink;
-import org.apache.flink.types.Row;
+
+import lombok.extern.slf4j.Slf4j;
 
 import java.net.URL;
+import java.util.HashMap;
 import java.util.List;
+import java.util.Map;
 import java.util.Optional;
 import java.util.stream.Collectors;
 
@@ -52,6 +60,7 @@ import static org.apache.seatunnel.api.common.CommonOptions.PLUGIN_NAME;
 import static org.apache.seatunnel.api.common.SeaTunnelAPIErrorCode.HANDLE_SAVE_MODE_FAILED;
 
 @SuppressWarnings({"unchecked", "rawtypes"})
+@Slf4j
 public class SinkExecuteProcessor
         extends FlinkAbstractPluginExecuteProcessor<Optional<? extends Factory>> {
 
@@ -97,58 +106,77 @@ public class SinkExecuteProcessor
                     fromSourceTable(sinkConfig, upstreamDataStreams).orElse(input);
             Optional<? extends Factory> factory = plugins.get(i);
             boolean fallBack = !factory.isPresent() || isFallback(factory.get());
-            SeaTunnelSink sink;
+            Map<String, SeaTunnelSink> sinks = new HashMap<>();
             if (fallBack) {
-                sink =
-                        fallbackCreateSink(
-                                sinkPluginDiscovery,
-                                PluginIdentifier.of(
-                                        ENGINE_TYPE,
-                                        PLUGIN_TYPE,
-                                        sinkConfig.getString(PLUGIN_NAME.key())),
-                                sinkConfig);
-                sink.setJobContext(jobContext);
-                // TODO support sink multi sink
-                SeaTunnelRowType sourceType =
-                        stream.getCatalogTables().get(0).getSeaTunnelRowType();
-                sink.setTypeInfo(sourceType);
+                for (CatalogTable catalogTable : stream.getCatalogTables()) {
+                    SeaTunnelSink fallBackSink =
+                            fallbackCreateSink(
+                                    sinkPluginDiscovery,
+                                    PluginIdentifier.of(
+                                            ENGINE_TYPE,
+                                            PLUGIN_TYPE,
+                                            sinkConfig.getString(PLUGIN_NAME.key())),
+                                    sinkConfig);
+                    fallBackSink.setJobContext(jobContext);
+                    SeaTunnelRowType sourceType = catalogTable.getSeaTunnelRowType();
+                    fallBackSink.setTypeInfo(sourceType);
+                    handleSaveMode(fallBackSink);
+                    TableIdentifier tableId = catalogTable.getTableId();
+                    String tableIdName = tableId.toTablePath().toString();
+                    sinks.put(tableIdName, fallBackSink);
+                }
             } else {
-                // TODO support sink multi sink
-                TableSinkFactoryContext context =
-                        TableSinkFactoryContext.replacePlaceholderAndCreate(
-                                stream.getCatalogTables().get(0),
-                                ReadonlyConfig.fromConfig(sinkConfig),
-                                classLoader,
-                                ((TableSinkFactory) factory.get())
-                                        .excludeTablePlaceholderReplaceKeys());
-                ConfigValidator.of(context.getOptions()).validate(factory.get().optionRule());
-                sink = ((TableSinkFactory) factory.get()).createSink(context).createSink();
-                sink.setJobContext(jobContext);
-            }
-            if (SupportSaveMode.class.isAssignableFrom(sink.getClass())) {
-                SupportSaveMode saveModeSink = (SupportSaveMode) sink;
-                Optional<SaveModeHandler> saveModeHandler = saveModeSink.getSaveModeHandler();
-                if (saveModeHandler.isPresent()) {
-                    try (SaveModeHandler handler = saveModeHandler.get()) {
-                        new SaveModeExecuteWrapper(handler).execute();
-                    } catch (Exception e) {
-                        throw new SeaTunnelRuntimeException(HANDLE_SAVE_MODE_FAILED, e);
-                    }
+                for (CatalogTable catalogTable : stream.getCatalogTables()) {
+                    SeaTunnelSink seaTunnelSink;
+                    TableSinkFactoryContext context =
+                            TableSinkFactoryContext.replacePlaceholderAndCreate(
+                                    catalogTable,
+                                    ReadonlyConfig.fromConfig(sinkConfig),
+                                    classLoader,
+                                    ((TableSinkFactory) factory.get())
+                                            .excludeTablePlaceholderReplaceKeys());
+                    ConfigValidator.of(context.getOptions()).validate(factory.get().optionRule());
+                    seaTunnelSink =
+                            ((TableSinkFactory) factory.get()).createSink(context).createSink();
+                    seaTunnelSink.setJobContext(jobContext);
+                    handleSaveMode(seaTunnelSink);
+                    TableIdentifier tableId = catalogTable.getTableId();
+                    String tableIdName = tableId.toTablePath().toString();
+                    sinks.put(tableIdName, seaTunnelSink);
                 }
             }
-            DataStreamSink<Row> dataStreamSink =
+            SeaTunnelSink sink =
+                    tryGenerateMultiTableSink(
+                            sinks, ReadonlyConfig.fromConfig(sinkConfig), classLoader);
+            boolean sinkParallelism = sinkConfig.hasPath(CommonOptions.PARALLELISM.key());
+            boolean envParallelism = envConfig.hasPath(CommonOptions.PARALLELISM.key());
+            int parallelism =
+                    sinkParallelism
+                            ? sinkConfig.getInt(CommonOptions.PARALLELISM.key())
+                            : envParallelism
+                                    ? envConfig.getInt(CommonOptions.PARALLELISM.key())
+                                    : 1;
+            DataStreamSink<SeaTunnelRow> dataStreamSink =
                     stream.getDataStream()
-                            .sinkTo(new FlinkSink<>(sink, stream.getCatalogTables().get(0)))
+                            .sinkTo(new FlinkSink<>(sink, stream.getCatalogTables(), parallelism))
                             .name(String.format("%s-Sink", sink.getPluginName()));
-            if (sinkConfig.hasPath(CommonOptions.PARALLELISM.key())) {
-                int parallelism = sinkConfig.getInt(CommonOptions.PARALLELISM.key());
-                dataStreamSink.setParallelism(parallelism);
-            }
+            dataStreamSink.setParallelism(parallelism);
         }
         // the sink is the last stream
         return null;
     }
 
+    // if not support multi table, rollback
+    public SeaTunnelSink tryGenerateMultiTableSink(
+            Map<String, SeaTunnelSink> sinks, ReadonlyConfig sinkConfig, ClassLoader classLoader) {
+        if (sinks.values().stream().anyMatch(sink -> !(sink instanceof SupportMultiTableSink))) {
+            log.info("Unsupported multi table sink api, rollback to sink template");
+            // choose the first sink
+            return sinks.values().iterator().next();
+        }
+        return FactoryUtil.createMultiTableSink(sinks, sinkConfig, classLoader);
+    }
+
     public boolean isFallback(Factory factory) {
         try {
             ((TableSinkFactory) factory).createSink(null);
@@ -170,4 +198,19 @@ public class SinkExecuteProcessor
         source.prepare(pluginConfig);
         return source;
     }
+
+    public void handleSaveMode(SeaTunnelSink seaTunnelSink) {
+        if (seaTunnelSink instanceof SupportSaveMode) {
+            SupportSaveMode saveModeSink = (SupportSaveMode) seaTunnelSink;
+            Optional<SaveModeHandler> saveModeHandler = saveModeSink.getSaveModeHandler();
+            if (saveModeHandler.isPresent()) {
+                try (SaveModeHandler handler = saveModeHandler.get()) {
+                    handler.open();
+                    new SaveModeExecuteWrapper(handler).execute();
+                } catch (Exception e) {
+                    throw new SeaTunnelRuntimeException(HANDLE_SAVE_MODE_FAILED, e);
+                }
+            }
+        }
+    }
 }
