@@ -25,17 +25,27 @@ import org.apache.seatunnel.e2e.common.container.TestHelper;
 import org.apache.seatunnel.e2e.common.junit.DisabledOnContainer;
 import org.apache.seatunnel.e2e.common.util.ContainerUtil;
 
+import org.apache.commons.lang3.StringUtils;
+
 import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.TestTemplate;
 import org.testcontainers.containers.GenericContainer;
 import org.testcontainers.containers.output.Slf4jLogConsumer;
 import org.testcontainers.lifecycle.Startables;
+import org.testcontainers.shaded.com.github.dockerjava.core.command.ExecStartResultCallback;
 
+import com.github.dockerjava.api.command.ExecCreateCmdResponse;
+import lombok.SneakyThrows;
 import lombok.extern.slf4j.Slf4j;
 
+import java.io.ByteArrayOutputStream;
 import java.io.IOException;
+import java.nio.charset.StandardCharsets;
+import java.util.ArrayList;
 import java.util.Collections;
+import java.util.List;
 import java.util.stream.Stream;
 
 @DisabledOnContainer(
@@ -94,6 +104,11 @@ public class FtpFileIT extends TestSuiteBase implements TestResource {
                 "/home/vsftpd/seatunnel/tmp/seatunnel/read/text/name=tyrantlucifer/hobby=coding/e2e.txt",
                 ftpContainer);
 
+        ContainerUtil.copyFileIntoContainers(
+                "/text/e2e-txt.zip",
+                "/home/vsftpd/seatunnel/tmp/seatunnel/read/zip/txt/single/e2e-txt.zip",
+                ftpContainer);
+
         ContainerUtil.copyFileIntoContainers(
                 "/excel/e2e.xlsx",
                 "/home/vsftpd/seatunnel/tmp/seatunnel/read/excel/name=tyrantlucifer/hobby=coding/e2e.xlsx",
@@ -131,6 +146,8 @@ public class FtpFileIT extends TestSuiteBase implements TestResource {
         helper.execute("/text/ftp_file_text_to_assert.conf");
         // test read ftp text file with projection
         helper.execute("/text/ftp_file_text_projection_to_assert.conf");
+        // test read ftp zip text file
+        helper.execute("/text/ftp_file_zip_text_to_assert.conf");
         // test write ftp json file
         helper.execute("/json/fake_to_ftp_file_json.conf");
         // test read ftp json file
@@ -143,6 +160,69 @@ public class FtpFileIT extends TestSuiteBase implements TestResource {
         helper.execute("/excel/fake_source_to_ftp_root_path_excel.conf");
     }
 
+    @TestTemplate
+    @DisabledOnContainer(
+            value = {},
+            type = {EngineType.FLINK},
+            disabledReason = "Flink dosen't support multi-table at now")
+    public void testMultipleTableAndSaveMode(TestContainer container)
+            throws IOException, InterruptedException {
+        TestHelper helper = new TestHelper(container);
+        // test mult table and save_mode:RECREATE_SCHEMA DROP_DATA
+        String homePath = "/home/vsftpd/seatunnel";
+        String path1 = "/tmp/seatunnel_mult/text/source_1";
+        String path2 = "/tmp/seatunnel_mult/text/source_2";
+        Assertions.assertEquals(getFileListFromContainer(homePath + path1).size(), 0);
+        Assertions.assertEquals(getFileListFromContainer(homePath + path2).size(), 0);
+        helper.execute("/text/multiple_table_fake_to_ftp_file_text.conf");
+        Assertions.assertEquals(getFileListFromContainer(homePath + path1).size(), 1);
+        Assertions.assertEquals(getFileListFromContainer(homePath + path2).size(), 1);
+        helper.execute("/text/multiple_table_fake_to_ftp_file_text.conf");
+        Assertions.assertEquals(getFileListFromContainer(homePath + path1).size(), 1);
+        Assertions.assertEquals(getFileListFromContainer(homePath + path2).size(), 1);
+        // test mult table and save_mode:CREATE_SCHEMA_WHEN_NOT_EXIST APPEND_DATA
+        String path3 = "/tmp/seatunnel_mult2/text/source_1";
+        String path4 = "/tmp/seatunnel_mult2/text/source_2";
+        Assertions.assertEquals(getFileListFromContainer(homePath + path3).size(), 0);
+        Assertions.assertEquals(getFileListFromContainer(homePath + path4).size(), 0);
+        helper.execute("/text/multiple_table_fake_to_ftp_file_text_2.conf");
+        Assertions.assertEquals(getFileListFromContainer(homePath + path3).size(), 1);
+        Assertions.assertEquals(getFileListFromContainer(homePath + path4).size(), 1);
+        helper.execute("/text/multiple_table_fake_to_ftp_file_text_2.conf");
+        Assertions.assertEquals(getFileListFromContainer(homePath + path3).size(), 2);
+        Assertions.assertEquals(getFileListFromContainer(homePath + path4).size(), 2);
+    }
+
+    @SneakyThrows
+    private List<String> getFileListFromContainer(String path) {
+        String command = "ls -1 " + path;
+        ExecCreateCmdResponse execCreateCmdResponse =
+                dockerClient
+                        .execCreateCmd(ftpContainer.getContainerId())
+                        .withCmd("sh", "-c", command)
+                        .withAttachStdout(true)
+                        .withAttachStderr(true)
+                        .exec();
+
+        ByteArrayOutputStream outputStream = new ByteArrayOutputStream();
+        dockerClient
+                .execStartCmd(execCreateCmdResponse.getId())
+                .exec(new ExecStartResultCallback(outputStream, System.err))
+                .awaitCompletion();
+
+        String output = new String(outputStream.toByteArray(), StandardCharsets.UTF_8).trim();
+        List<String> fileList = new ArrayList<>();
+        log.info("container path file list is :{}", output);
+        String[] files = output.split("\n");
+        for (String file : files) {
+            if (StringUtils.isNotEmpty(file)) {
+                log.info("container path file name is :{}", file);
+                fileList.add(file);
+            }
+        }
+        return fileList;
+    }
+
     @AfterAll
     @Override
     public void tearDown() {
