@@ -23,18 +23,20 @@ import org.apache.seatunnel.shade.com.fasterxml.jackson.databind.ObjectMapper;
 
 import org.apache.seatunnel.e2e.common.TestResource;
 import org.apache.seatunnel.e2e.common.TestSuiteBase;
-import org.apache.seatunnel.e2e.common.container.EngineType;
+import org.apache.seatunnel.e2e.common.container.ContainerExtendedFactory;
 import org.apache.seatunnel.e2e.common.container.TestContainer;
-import org.apache.seatunnel.e2e.common.junit.DisabledOnContainer;
+import org.apache.seatunnel.e2e.common.junit.TestContainerExtension;
 
 import org.junit.jupiter.api.AfterAll;
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.TestTemplate;
 import org.mockserver.client.MockServerClient;
+import org.mockserver.model.ClearType;
 import org.mockserver.model.Format;
 import org.testcontainers.containers.Container;
 import org.testcontainers.containers.GenericContainer;
+import org.testcontainers.containers.PostgreSQLContainer;
 import org.testcontainers.containers.output.Slf4jLogConsumer;
 import org.testcontainers.containers.wait.strategy.HttpWaitStrategy;
 import org.testcontainers.lifecycle.Startables;
@@ -46,19 +48,30 @@ import com.google.common.collect.Lists;
 import lombok.EqualsAndHashCode;
 import lombok.Getter;
 import lombok.Setter;
+import lombok.extern.slf4j.Slf4j;
 
 import java.io.File;
 import java.io.IOException;
 import java.math.BigDecimal;
 import java.net.URL;
+import java.sql.Connection;
+import java.sql.DriverManager;
+import java.sql.ResultSet;
+import java.sql.SQLException;
+import java.sql.Statement;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Optional;
+import java.util.concurrent.CompletableFuture;
+import java.util.concurrent.TimeUnit;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
 
+import static org.awaitility.Awaitility.await;
+import static org.awaitility.Awaitility.given;
 import static org.mockserver.model.HttpRequest.request;
 
+@Slf4j
 public class HttpIT extends TestSuiteBase implements TestResource {
 
     private static final String TMP_DIR = "/tmp";
@@ -71,9 +84,31 @@ public class HttpIT extends TestSuiteBase implements TestResource {
 
     private MockServerClient mockServerClient;
 
+    private static final String POSTGRESQL_SCHEMA = "public";
+    private static final String SINK_TABLE_1 = "sink";
+    private static final Integer MAX_COUNT = 15;
+    private static final String COUNT_QUERY = "select count(*) from sink";
+
+    private static final String PG_IMAGE = "postgres:14-alpine";
+    private static final String PG_DRIVER_JAR =
+            "https://repo1.maven.org/maven2/org/postgresql/postgresql/42.3.3/postgresql-42.3.3.jar";
+    private PostgreSQLContainer<?> postgreSQLContainer;
+
+    @TestContainerExtension
+    private final ContainerExtendedFactory extendedFactory =
+            container -> {
+                Container.ExecResult extraCommands =
+                        container.execInContainer(
+                                "bash",
+                                "-c",
+                                "mkdir -p /tmp/seatunnel/plugins/Jdbc/lib && cd /tmp/seatunnel/plugins/Jdbc/lib && curl -O "
+                                        + PG_DRIVER_JAR);
+                Assertions.assertEquals(0, extraCommands.getExitCode());
+            };
+
     @BeforeAll
     @Override
-    public void startUp() {
+    public void startUp() throws ClassNotFoundException {
         Optional<URL> resource =
                 Optional.ofNullable(HttpIT.class.getResource(getMockServerConfig()));
         this.mockserverContainer =
@@ -101,6 +136,22 @@ public class HttpIT extends TestSuiteBase implements TestResource {
         Startables.deepStart(Stream.of(mockserverContainer)).join();
         mockServerClient = new MockServerClient("127.0.0.1", 1080);
         fillMockRecords();
+
+        postgreSQLContainer =
+                new PostgreSQLContainer<>(DockerImageName.parse(PG_IMAGE))
+                        .withNetwork(TestSuiteBase.NETWORK)
+                        .withNetworkAliases("postgresql")
+                        .withLogConsumer(
+                                new Slf4jLogConsumer(DockerLoggerFactory.getLogger(PG_IMAGE)));
+        Startables.deepStart(Stream.of(postgreSQLContainer)).join();
+        log.info("PostgreSQL container started");
+        Class.forName(postgreSQLContainer.getDriverClassName());
+        given().ignoreExceptions()
+                .await()
+                .atLeast(100, TimeUnit.MILLISECONDS)
+                .pollInterval(500, TimeUnit.MILLISECONDS)
+                .atMost(2, TimeUnit.MINUTES)
+                .untilAsserted(this::initializeJdbcTable);
     }
 
     private static void fillMockRecords() {
@@ -150,6 +201,71 @@ public class HttpIT extends TestSuiteBase implements TestResource {
         if (mockServerClient != null) {
             mockServerClient.close();
         }
+        if (postgreSQLContainer != null) {
+            postgreSQLContainer.stop();
+        }
+    }
+
+    @TestTemplate
+    public void testStreamingSourceToPostgresqlSink(TestContainer container) {
+        try {
+            CompletableFuture.supplyAsync(
+                    () -> {
+                        try {
+                            Container.ExecResult execResult1 =
+                                    container.executeJob("/http_streaming_json_to_postgresql.conf");
+                        } catch (Exception e) {
+                            log.error("Commit task exception :" + e.getMessage());
+                            throw new RuntimeException(e);
+                        }
+                        return null;
+                    });
+            await().atMost(60000, TimeUnit.MILLISECONDS)
+                    .untilAsserted(
+                            () -> {
+                                Long count = queryCount(COUNT_QUERY);
+                                Assertions.assertTrue(
+                                        count >= MAX_COUNT,
+                                        "Actual value should be greater than expected value");
+                            });
+        } finally {
+            log.info("clear schema:{}", SINK_TABLE_1);
+            clearTable(POSTGRESQL_SCHEMA, SINK_TABLE_1);
+        }
+    }
+
+    private Long queryCount(String sql) {
+        try (Connection connection = getJdbcConnection()) {
+            ResultSet resultSet = connection.createStatement().executeQuery(sql);
+            if (resultSet.next()) {
+
+                return resultSet.getLong(1);
+            }
+            return 0L;
+        } catch (SQLException e) {
+            throw new RuntimeException(e);
+        }
+    }
+
+    private Connection getJdbcConnection() throws SQLException {
+        return DriverManager.getConnection(
+                postgreSQLContainer.getJdbcUrl(),
+                postgreSQLContainer.getUsername(),
+                postgreSQLContainer.getPassword());
+    }
+
+    private void executeSql(String sql) {
+        try (Connection connection = getJdbcConnection();
+                Statement statement = connection.createStatement()) {
+            statement.execute("SET search_path TO inventory;");
+            statement.execute(sql);
+        } catch (SQLException e) {
+            throw new RuntimeException(e);
+        }
+    }
+
+    private void clearTable(String database, String tableName) {
+        executeSql("truncate table " + database + "." + tableName);
     }
 
     @TestTemplate
@@ -228,12 +344,12 @@ public class HttpIT extends TestSuiteBase implements TestResource {
 
         Container.ExecResult execResult18 = container.executeJob("/httpnoschema_to_http.conf");
         Assertions.assertEquals(0, execResult18.getExitCode());
+
+        Container.ExecResult execResult19 =
+                container.executeJob("/http_page_increase_start_num.conf");
+        Assertions.assertEquals(0, execResult19.getExitCode());
     }
 
-    @DisabledOnContainer(
-            value = {},
-            type = {EngineType.SPARK, EngineType.FLINK},
-            disabledReason = "Currently SPARK/FLINK do not support multiple table read")
     @TestTemplate
     public void testMultiTableHttp(TestContainer container)
             throws IOException, InterruptedException {
@@ -245,6 +361,9 @@ public class HttpIT extends TestSuiteBase implements TestResource {
                 mockServerClient.retrieveRecordedRequests(
                         request().withPath("/example/httpMultiTableContentSink").withMethod("POST"),
                         Format.JSON);
+        mockServerClient.clear(
+                request().withPath("/example/httpMultiTableContentSink").withMethod("POST"),
+                ClearType.LOG);
         List<Record> recordResponse =
                 objectMapper.readValue(mockResponse, new TypeReference<List<Record>>() {});
         recordResponse =
@@ -257,6 +376,24 @@ public class HttpIT extends TestSuiteBase implements TestResource {
         Assertions.assertIterableEquals(records, recordResponse);
     }
 
+    private void initializeJdbcTable() {
+        try (Connection connection =
+                DriverManager.getConnection(
+                        postgreSQLContainer.getJdbcUrl(),
+                        postgreSQLContainer.getUsername(),
+                        postgreSQLContainer.getPassword())) {
+            Statement statement = connection.createStatement();
+            String sink =
+                    "create table sink(\n"
+                            + "c_String varchar(255) NOT NULL PRIMARY KEY,\n"
+                            + "c_int INT\n"
+                            + ")";
+            statement.execute(sink);
+        } catch (SQLException e) {
+            throw new RuntimeException("Initializing PostgreSql table failed!", e);
+        }
+    }
+
     @Getter
     @Setter
     @EqualsAndHashCode
