@@ -22,9 +22,7 @@ import org.apache.seatunnel.api.table.type.SeaTunnelRow;
 import org.apache.seatunnel.e2e.common.TestResource;
 import org.apache.seatunnel.e2e.common.TestSuiteBase;
 import org.apache.seatunnel.e2e.common.container.ContainerExtendedFactory;
-import org.apache.seatunnel.e2e.common.container.EngineType;
 import org.apache.seatunnel.e2e.common.container.TestContainer;
-import org.apache.seatunnel.e2e.common.junit.DisabledOnContainer;
 import org.apache.seatunnel.e2e.common.junit.TestContainerExtension;
 
 import org.apache.commons.lang3.tuple.Pair;
@@ -169,10 +167,6 @@ public class JdbcMysqlMultipleTablesIT extends TestSuiteBase implements TestReso
                 query(String.format("SELECT * FROM %s.%s", SINK_DATABASE, "table1")));
     }
 
-    @DisabledOnContainer(
-            value = {},
-            type = {EngineType.SPARK, EngineType.FLINK},
-            disabledReason = "Currently SPARK and FLINK do not support multiple tables")
     @TestTemplate
     public void testMysqlJdbcMultipleTableE2e(TestContainer container)
             throws IOException, InterruptedException, SQLException {
