@@ -84,12 +84,10 @@ public class JdbcGreenplumIT extends AbstractJdbcIT {
                 .configFile(CONFIG_FILE)
                 .insertSql(insertSql)
                 .testData(testDataSet)
+                .tablePathFullName(GREENPLUM_SOURCE)
                 .build();
     }
 
-    @Override
-    void compareResult(String executeKey) {}
-
     @Override
     String driverUrl() {
         return "https://repo1.maven.org/maven2/org/postgresql/postgresql/42.3.3/postgresql-42.3.3.jar";
