@@ -19,9 +19,15 @@ package org.apache.seatunnel.e2e.connector.kafka;
 
 import org.apache.seatunnel.shade.com.fasterxml.jackson.databind.ObjectMapper;
 import org.apache.seatunnel.shade.com.fasterxml.jackson.databind.node.ObjectNode;
+import org.apache.seatunnel.shade.com.typesafe.config.Config;
+import org.apache.seatunnel.shade.com.typesafe.config.ConfigFactory;
 
+import org.apache.seatunnel.api.configuration.ReadonlyConfig;
 import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.api.table.catalog.CatalogTableUtil;
+import org.apache.seatunnel.api.table.catalog.PhysicalColumn;
+import org.apache.seatunnel.api.table.catalog.TableIdentifier;
+import org.apache.seatunnel.api.table.catalog.TableSchema;
 import org.apache.seatunnel.api.table.type.ArrayType;
 import org.apache.seatunnel.api.table.type.BasicType;
 import org.apache.seatunnel.api.table.type.DecimalType;
@@ -40,6 +46,7 @@ import org.apache.seatunnel.e2e.common.container.TestContainer;
 import org.apache.seatunnel.e2e.common.container.TestContainerId;
 import org.apache.seatunnel.e2e.common.junit.DisabledOnContainer;
 import org.apache.seatunnel.format.avro.AvroDeserializationSchema;
+import org.apache.seatunnel.format.protobuf.ProtobufDeserializationSchema;
 import org.apache.seatunnel.format.text.TextSerializationSchema;
 
 import org.apache.kafka.clients.admin.AdminClient;
@@ -71,8 +78,13 @@ import org.testcontainers.utility.DockerLoggerFactory;
 
 import lombok.extern.slf4j.Slf4j;
 
+import java.io.File;
+import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.math.BigDecimal;
+import java.net.URISyntaxException;
+import java.net.URL;
+import java.nio.file.Paths;
 import java.time.Duration;
 import java.time.LocalDate;
 import java.time.LocalDateTime;
@@ -85,6 +97,7 @@ import java.util.Map;
 import java.util.Properties;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.TimeUnit;
+import java.util.stream.IntStream;
 import java.util.stream.Stream;
 
 @Slf4j
@@ -126,7 +139,8 @@ public class KafkaIT extends TestSuiteBase implements TestResource {
                         "test_topic_source",
                         SEATUNNEL_ROW_TYPE,
                         DEFAULT_FORMAT,
-                        DEFAULT_FIELD_DELIMITER);
+                        DEFAULT_FIELD_DELIMITER,
+                        null);
         generateTestData(serializer::serializeRow, 0, 100);
     }
 
@@ -259,7 +273,8 @@ public class KafkaIT extends TestSuiteBase implements TestResource {
                         "test_topic_json",
                         SEATUNNEL_ROW_TYPE,
                         DEFAULT_FORMAT,
-                        DEFAULT_FIELD_DELIMITER);
+                        DEFAULT_FIELD_DELIMITER,
+                        null);
         generateTestData(row -> serializer.serializeRow(row), 0, 100);
         Container.ExecResult execResult =
                 container.executeJob("/jsonFormatIT/kafka_source_json_to_console.conf");
@@ -274,7 +289,8 @@ public class KafkaIT extends TestSuiteBase implements TestResource {
                         "test_topic_error_message",
                         SEATUNNEL_ROW_TYPE,
                         DEFAULT_FORMAT,
-                        DEFAULT_FIELD_DELIMITER);
+                        DEFAULT_FIELD_DELIMITER,
+                        null);
         generateTestData(row -> serializer.serializeRow(row), 0, 100);
         Container.ExecResult execResult =
                 container.executeJob(
@@ -290,7 +306,8 @@ public class KafkaIT extends TestSuiteBase implements TestResource {
                         "test_topic_error_message",
                         SEATUNNEL_ROW_TYPE,
                         DEFAULT_FORMAT,
-                        DEFAULT_FIELD_DELIMITER);
+                        DEFAULT_FIELD_DELIMITER,
+                        null);
         generateTestData(row -> serializer.serializeRow(row), 0, 100);
         Container.ExecResult execResult =
                 container.executeJob(
@@ -314,7 +331,8 @@ public class KafkaIT extends TestSuiteBase implements TestResource {
                         "test_topic_group",
                         SEATUNNEL_ROW_TYPE,
                         DEFAULT_FORMAT,
-                        DEFAULT_FIELD_DELIMITER);
+                        DEFAULT_FIELD_DELIMITER,
+                        null);
         generateTestData(row -> serializer.serializeRow(row), 100, 150);
         testKafkaGroupOffsetsToConsole(container);
     }
@@ -331,7 +349,8 @@ public class KafkaIT extends TestSuiteBase implements TestResource {
                         "test_topic_group_with_commit_offset",
                         SEATUNNEL_ROW_TYPE,
                         DEFAULT_FORMAT,
-                        DEFAULT_FIELD_DELIMITER);
+                        DEFAULT_FIELD_DELIMITER,
+                        null);
         generateTestData(row -> serializer.serializeRow(row), 0, 100);
         testKafkaGroupOffsetsToConsoleWithCommitOffset(container);
     }
@@ -456,7 +475,8 @@ public class KafkaIT extends TestSuiteBase implements TestResource {
                         "test_avro_topic",
                         SEATUNNEL_ROW_TYPE,
                         MessageFormat.AVRO,
-                        DEFAULT_FIELD_DELIMITER);
+                        DEFAULT_FIELD_DELIMITER,
+                        null);
         int start = 0;
         int end = 100;
         generateTestData(row -> serializer.serializeRow(row), start, end);
@@ -504,6 +524,260 @@ public class KafkaIT extends TestSuiteBase implements TestResource {
                 });
     }
 
+    @TestTemplate
+    public void testFakeSourceToKafkaProtobufFormat(TestContainer container)
+            throws IOException, InterruptedException, URISyntaxException {
+
+        // Execute the job and verify the exit code
+        Container.ExecResult execResult =
+                container.executeJob("/protobuf/fake_to_kafka_protobuf.conf");
+        Assertions.assertEquals(0, execResult.getExitCode(), execResult.getStderr());
+
+        // Define the SeaTunnelRowType for the address field
+        SeaTunnelRowType addressType =
+                new SeaTunnelRowType(
+                        new String[] {"city", "state", "street"},
+                        new SeaTunnelDataType<?>[] {
+                            BasicType.STRING_TYPE, BasicType.STRING_TYPE, BasicType.STRING_TYPE
+                        });
+
+        // Define the SeaTunnelRowType for the main schema
+        SeaTunnelRowType seaTunnelRowType =
+                new SeaTunnelRowType(
+                        new String[] {
+                            "c_int32",
+                            "c_int64",
+                            "c_float",
+                            "c_double",
+                            "c_bool",
+                            "c_string",
+                            "c_bytes",
+                            "Address",
+                            "attributes",
+                            "phone_numbers"
+                        },
+                        new SeaTunnelDataType<?>[] {
+                            BasicType.INT_TYPE,
+                            BasicType.LONG_TYPE,
+                            BasicType.FLOAT_TYPE,
+                            BasicType.DOUBLE_TYPE,
+                            BasicType.BOOLEAN_TYPE,
+                            BasicType.STRING_TYPE,
+                            PrimitiveByteArrayType.INSTANCE,
+                            addressType,
+                            new MapType<>(BasicType.STRING_TYPE, BasicType.FLOAT_TYPE),
+                            ArrayType.STRING_ARRAY_TYPE
+                        });
+
+        // Parse the configuration file
+        String path = getTestConfigFile("/protobuf/fake_to_kafka_protobuf.conf");
+        Config config = ConfigFactory.parseFile(new File(path));
+        Config sinkConfig = config.getConfigList("sink").get(0);
+
+        // Prepare the schema properties
+        Map<String, String> schemaProperties = new HashMap<>();
+        schemaProperties.put(
+                "protobuf_message_name", sinkConfig.getString("protobuf_message_name"));
+        schemaProperties.put("protobuf_schema", sinkConfig.getString("protobuf_schema"));
+
+        // Build the table schema based on SeaTunnelRowType
+        TableSchema schema =
+                TableSchema.builder()
+                        .columns(
+                                Arrays.asList(
+                                        IntStream.range(0, seaTunnelRowType.getTotalFields())
+                                                .mapToObj(
+                                                        i ->
+                                                                PhysicalColumn.of(
+                                                                        seaTunnelRowType
+                                                                                .getFieldName(i),
+                                                                        seaTunnelRowType
+                                                                                .getFieldType(i),
+                                                                        0,
+                                                                        true,
+                                                                        null,
+                                                                        null))
+                                                .toArray(PhysicalColumn[]::new)))
+                        .build();
+
+        // Create the catalog table
+        CatalogTable catalogTable =
+                CatalogTable.of(
+                        TableIdentifier.of("", "", "", "test"),
+                        schema,
+                        schemaProperties,
+                        Collections.emptyList(),
+                        "It is converted from RowType and only has column information.");
+
+        // Initialize the Protobuf deserialization schema
+        ProtobufDeserializationSchema deserializationSchema =
+                new ProtobufDeserializationSchema(catalogTable);
+
+        // Retrieve and verify Kafka rows
+        List<SeaTunnelRow> kafkaRows =
+                getKafkaSTRow(
+                        "test_protobuf_topic_fake_source",
+                        value -> {
+                            try {
+                                return deserializationSchema.deserialize(value);
+                            } catch (IOException e) {
+                                throw new RuntimeException(e);
+                            }
+                        });
+
+        Assertions.assertEquals(16, kafkaRows.size());
+
+        // Validate the contents of each row
+        kafkaRows.forEach(
+                row -> {
+                    Assertions.assertInstanceOf(Integer.class, row.getField(0));
+                    Assertions.assertInstanceOf(Long.class, row.getField(1));
+                    Assertions.assertInstanceOf(Float.class, row.getField(2));
+                    Assertions.assertInstanceOf(Double.class, row.getField(3));
+                    Assertions.assertInstanceOf(Boolean.class, row.getField(4));
+                    Assertions.assertInstanceOf(String.class, row.getField(5));
+                    Assertions.assertInstanceOf(byte[].class, row.getField(6));
+                    Assertions.assertInstanceOf(SeaTunnelRow.class, row.getField(7));
+                    Assertions.assertInstanceOf(Map.class, row.getField(8));
+                    Assertions.assertInstanceOf(String[].class, row.getField(9));
+                });
+    }
+
+    @TestTemplate
+    public void testKafkaProtobufToAssert(TestContainer container)
+            throws IOException, InterruptedException, URISyntaxException {
+
+        String confFile = "/protobuf/kafka_protobuf_to_assert.conf";
+        String path = getTestConfigFile(confFile);
+        Config config = ConfigFactory.parseFile(new File(path));
+        Config sinkConfig = config.getConfigList("source").get(0);
+        ReadonlyConfig readonlyConfig = ReadonlyConfig.fromConfig(sinkConfig);
+        SeaTunnelRowType seaTunnelRowType = buildSeaTunnelRowType();
+
+        // Prepare schema properties
+        Map<String, String> schemaProperties = new HashMap<>();
+        schemaProperties.put(
+                "protobuf_message_name", sinkConfig.getString("protobuf_message_name"));
+        schemaProperties.put("protobuf_schema", sinkConfig.getString("protobuf_schema"));
+
+        // Build the table schema
+        TableSchema schema =
+                TableSchema.builder()
+                        .columns(
+                                Arrays.asList(
+                                        IntStream.range(0, seaTunnelRowType.getTotalFields())
+                                                .mapToObj(
+                                                        i ->
+                                                                PhysicalColumn.of(
+                                                                        seaTunnelRowType
+                                                                                .getFieldName(i),
+                                                                        seaTunnelRowType
+                                                                                .getFieldType(i),
+                                                                        0,
+                                                                        true,
+                                                                        null,
+                                                                        null))
+                                                .toArray(PhysicalColumn[]::new)))
+                        .build();
+
+        // Create catalog table
+        CatalogTable catalogTable =
+                CatalogTable.of(
+                        TableIdentifier.of("", "", "", "test"),
+                        schema,
+                        schemaProperties,
+                        Collections.emptyList(),
+                        "It is converted from RowType and only has column information.");
+
+        // Initialize the Protobuf deserialization schema
+        ProtobufDeserializationSchema deserializationSchema =
+                new ProtobufDeserializationSchema(catalogTable);
+
+        // Create serializer
+        DefaultSeaTunnelRowSerializer serializer =
+                DefaultSeaTunnelRowSerializer.create(
+                        "test_protobuf_topic_fake_source",
+                        seaTunnelRowType,
+                        MessageFormat.PROTOBUF,
+                        DEFAULT_FIELD_DELIMITER,
+                        readonlyConfig);
+
+        // Produce records to Kafka
+        IntStream.range(0, 20)
+                .forEach(
+                        i -> {
+                            try {
+                                SeaTunnelRow originalRow = buildSeaTunnelRow();
+                                ProducerRecord<byte[], byte[]> producerRecord =
+                                        serializer.serializeRow(originalRow);
+                                producer.send(producerRecord).get();
+                            } catch (InterruptedException | ExecutionException e) {
+                                throw new RuntimeException("Error sending Kafka message", e);
+                            }
+                        });
+
+        producer.flush();
+
+        // Execute the job and validate
+        Container.ExecResult execResult = container.executeJob(confFile);
+        Assertions.assertEquals(0, execResult.getExitCode(), execResult.getStderr());
+
+        // Retrieve and verify Kafka rows
+        List<SeaTunnelRow> kafkaSTRow =
+                getKafkaSTRow(
+                        "test_protobuf_topic_fake_source",
+                        value -> {
+                            try {
+                                return deserializationSchema.deserialize(value);
+                            } catch (IOException e) {
+                                throw new RuntimeException("Error deserializing Kafka message", e);
+                            }
+                        });
+
+        // Prepare expected values for assertions
+        SeaTunnelRow expectedAddress = new SeaTunnelRow(3);
+        expectedAddress.setField(0, "city_value");
+        expectedAddress.setField(1, "state_value");
+        expectedAddress.setField(2, "street_value");
+
+        Map<String, Float> expectedAttributesMap = new HashMap<>();
+        expectedAttributesMap.put("k1", 0.1F);
+        expectedAttributesMap.put("k2", 2.3F);
+
+        String[] expectedPhoneNumbers = {"1", "2"};
+
+        // Assertions
+        Assertions.assertEquals(20, kafkaSTRow.size());
+        kafkaSTRow.forEach(
+                row -> {
+                    Assertions.assertAll(
+                            "Verify row fields",
+                            () -> Assertions.assertEquals(123, (int) row.getField(0)),
+                            () -> Assertions.assertEquals(123123123123L, (long) row.getField(1)),
+                            () -> Assertions.assertEquals(0.123f, (float) row.getField(2)),
+                            () -> Assertions.assertEquals(0.123d, (double) row.getField(3)),
+                            () -> Assertions.assertFalse((boolean) row.getField(4)),
+                            () -> Assertions.assertEquals("test data", row.getField(5).toString()),
+                            () ->
+                                    Assertions.assertArrayEquals(
+                                            new byte[] {1, 2, 3}, (byte[]) row.getField(6)),
+                            () -> Assertions.assertEquals(expectedAddress, row.getField(7)),
+                            () -> Assertions.assertEquals(expectedAttributesMap, row.getField(8)),
+                            () ->
+                                    Assertions.assertArrayEquals(
+                                            expectedPhoneNumbers, (String[]) row.getField(9)));
+                });
+    }
+
+    public static String getTestConfigFile(String configFile)
+            throws FileNotFoundException, URISyntaxException {
+        URL resource = KafkaIT.class.getResource(configFile);
+        if (resource == null) {
+            throw new FileNotFoundException("Can't find config file: " + configFile);
+        }
+        return Paths.get(resource.toURI()).toString();
+    }
+
     public void testKafkaLatestToConsole(TestContainer container)
             throws IOException, InterruptedException {
         Container.ExecResult execResult =
@@ -759,4 +1033,68 @@ public class KafkaIT extends TestSuiteBase implements TestResource {
     interface ConsumerRecordConverter {
         SeaTunnelRow convert(byte[] value);
     }
+
+    private SeaTunnelRow buildSeaTunnelRow() {
+        SeaTunnelRow seaTunnelRow = new SeaTunnelRow(10);
+
+        Map<String, Float> attributesMap = new HashMap<>();
+        attributesMap.put("k1", 0.1F);
+        attributesMap.put("k2", 2.3F);
+
+        String[] phoneNumbers = {"1", "2"};
+        byte[] byteVal = {1, 2, 3};
+
+        SeaTunnelRow address = new SeaTunnelRow(3);
+        address.setField(0, "city_value");
+        address.setField(1, "state_value");
+        address.setField(2, "street_value");
+
+        seaTunnelRow.setField(0, 123);
+        seaTunnelRow.setField(1, 123123123123L);
+        seaTunnelRow.setField(2, 0.123f);
+        seaTunnelRow.setField(3, 0.123d);
+        seaTunnelRow.setField(4, false);
+        seaTunnelRow.setField(5, "test data");
+        seaTunnelRow.setField(6, byteVal);
+        seaTunnelRow.setField(7, address);
+        seaTunnelRow.setField(8, attributesMap);
+        seaTunnelRow.setField(9, phoneNumbers);
+
+        return seaTunnelRow;
+    }
+
+    private SeaTunnelRowType buildSeaTunnelRowType() {
+        SeaTunnelRowType addressType =
+                new SeaTunnelRowType(
+                        new String[] {"city", "state", "street"},
+                        new SeaTunnelDataType<?>[] {
+                            BasicType.STRING_TYPE, BasicType.STRING_TYPE, BasicType.STRING_TYPE
+                        });
+
+        return new SeaTunnelRowType(
+                new String[] {
+                    "c_int32",
+                    "c_int64",
+                    "c_float",
+                    "c_double",
+                    "c_bool",
+                    "c_string",
+                    "c_bytes",
+                    "Address",
+                    "attributes",
+                    "phone_numbers"
+                },
+                new SeaTunnelDataType<?>[] {
+                    BasicType.INT_TYPE,
+                    BasicType.LONG_TYPE,
+                    BasicType.FLOAT_TYPE,
+                    BasicType.DOUBLE_TYPE,
+                    BasicType.BOOLEAN_TYPE,
+                    BasicType.STRING_TYPE,
+                    PrimitiveByteArrayType.INSTANCE,
+                    addressType,
+                    new MapType<>(BasicType.STRING_TYPE, BasicType.FLOAT_TYPE),
+                    ArrayType.STRING_ARRAY_TYPE
+                });
+    }
 }
