@@ -282,7 +282,6 @@ public class PhysicalPlanGenerator {
 
                                 return new PhysicalVertex(
                                         atomicInteger.incrementAndGet(),
-                                        executorService,
                                         collect.size(),
                                         new TaskGroupDefaultImpl(
                                                 taskGroupLocation,
@@ -291,8 +290,9 @@ public class PhysicalPlanGenerator {
                                         flakeIdGenerator,
                                         pipelineIndex,
                                         totalPipelineNum,
-                                        sinkAction.getJarUrls(),
-                                        sinkAction.getConnectorJarIdentifiers(),
+                                        Collections.singletonList(sinkAction.getJarUrls()),
+                                        Collections.singletonList(
+                                                sinkAction.getConnectorJarIdentifiers()),
                                         jobImmutableInformation,
                                         initializationTimestamp,
                                         nodeEngine,
@@ -362,7 +362,7 @@ public class PhysicalPlanGenerator {
                                             new PhysicalExecutionFlow(
                                                     shuffleActionOfSinkFlow,
                                                     Collections.singletonList(sinkFlow));
-                                    setFlowConfig(shuffleFlow, parallelismIndex);
+                                    setFlowConfig(shuffleFlow);
 
                                     long taskGroupID =
                                             mixIDPrefixAndIndex(
@@ -389,7 +389,6 @@ public class PhysicalPlanGenerator {
                                     physicalVertices.add(
                                             new PhysicalVertex(
                                                     parallelismIndex,
-                                                    executorService,
                                                     shuffleFlow.getAction().getParallelism(),
                                                     new TaskGroupDefaultImpl(
                                                             taskGroupLocation,
@@ -400,8 +399,10 @@ public class PhysicalPlanGenerator {
                                                     flakeIdGenerator,
                                                     pipelineIndex,
                                                     totalPipelineNum,
-                                                    seaTunnelTask.getJarsUrl(),
-                                                    seaTunnelTask.getConnectorPluginJars(),
+                                                    Collections.singletonList(
+                                                            seaTunnelTask.getJarsUrl()),
+                                                    Collections.singletonList(
+                                                            seaTunnelTask.getConnectorPluginJars()),
                                                     jobImmutableInformation,
                                                     initializationTimestamp,
                                                     nodeEngine,
@@ -420,7 +421,7 @@ public class PhysicalPlanGenerator {
                                                     taskGroupID);
                                     TaskLocation taskLocation =
                                             new TaskLocation(taskGroupLocation, taskIDPrefix, i);
-                                    setFlowConfig(flow, i);
+                                    setFlowConfig(flow);
                                     SeaTunnelTask seaTunnelTask =
                                             new TransformSeaTunnelTask(
                                                     jobImmutableInformation.getJobId(),
@@ -432,7 +433,6 @@ public class PhysicalPlanGenerator {
                                     physicalVertices.add(
                                             new PhysicalVertex(
                                                     i,
-                                                    executorService,
                                                     flow.getAction().getParallelism(),
                                                     new TaskGroupDefaultImpl(
                                                             taskGroupLocation,
@@ -442,8 +442,10 @@ public class PhysicalPlanGenerator {
                                                     flakeIdGenerator,
                                                     pipelineIndex,
                                                     totalPipelineNum,
-                                                    seaTunnelTask.getJarsUrl(),
-                                                    seaTunnelTask.getConnectorPluginJars(),
+                                                    Collections.singletonList(
+                                                            seaTunnelTask.getJarsUrl()),
+                                                    Collections.singletonList(
+                                                            seaTunnelTask.getConnectorPluginJars()),
                                                     jobImmutableInformation,
                                                     initializationTimestamp,
                                                     nodeEngine,
@@ -488,7 +490,6 @@ public class PhysicalPlanGenerator {
 
                             return new PhysicalVertex(
                                     atomicInteger.incrementAndGet(),
-                                    executorService,
                                     sources.size(),
                                     new TaskGroupDefaultImpl(
                                             taskGroupLocation,
@@ -497,8 +498,8 @@ public class PhysicalPlanGenerator {
                                     flakeIdGenerator,
                                     pipelineIndex,
                                     totalPipelineNum,
-                                    t.getJarsUrl(),
-                                    t.getConnectorPluginJars(),
+                                    Collections.singletonList(t.getJarsUrl()),
+                                    Collections.singletonList(t.getConnectorPluginJars()),
                                     jobImmutableInformation,
                                     initializationTimestamp,
                                     nodeEngine,
@@ -536,7 +537,7 @@ public class PhysicalPlanGenerator {
                                         flows.stream()
                                                 .map(
                                                         f -> {
-                                                            setFlowConfig(f, finalParallelismIndex);
+                                                            setFlowConfig(f);
                                                             long taskIDPrefix =
                                                                     flowTaskIDPrefixMap
                                                                             .computeIfAbsent(
@@ -575,18 +576,15 @@ public class PhysicalPlanGenerator {
                                                         })
                                                 .peek(this::fillCheckpointPlan)
                                                 .collect(Collectors.toList());
-                                Set<URL> jars =
+                                List<Set<URL>> jars =
                                         taskList.stream()
-                                                .flatMap(task -> task.getJarsUrl().stream())
-                                                .collect(Collectors.toSet());
+                                                .map(SeaTunnelTask::getJarsUrl)
+                                                .collect(Collectors.toList());
 
-                                Set<ConnectorJarIdentifier> jarIdentifiers =
+                                List<Set<ConnectorJarIdentifier>> jarIdentifiers =
                                         taskList.stream()
-                                                .flatMap(
-                                                        task ->
-                                                                task.getConnectorPluginJars()
-                                                                        .stream())
-                                                .collect(Collectors.toSet());
+                                                .map(SeaTunnelTask::getConnectorPluginJars)
+                                                .collect(Collectors.toList());
 
                                 if (taskList.stream()
                                         .anyMatch(TransformSeaTunnelTask.class::isInstance)) {
@@ -612,7 +610,6 @@ public class PhysicalPlanGenerator {
                                     t.add(
                                             new PhysicalVertex(
                                                     i,
-                                                    executorService,
                                                     flow.getAction().getParallelism(),
                                                     taskGroup,
                                                     flakeIdGenerator,
@@ -629,7 +626,6 @@ public class PhysicalPlanGenerator {
                                     t.add(
                                             new PhysicalVertex(
                                                     i,
-                                                    executorService,
                                                     flow.getAction().getParallelism(),
                                                     new TaskGroupDefaultImpl(
                                                             taskGroupLocation,
@@ -671,10 +667,9 @@ public class PhysicalPlanGenerator {
      * set config for flow, some flow should have config support for execute on task.
      *
      * @param f flow
-     * @param parallelismIndex the parallelism index of flow
      */
     @SuppressWarnings("unchecked")
-    private void setFlowConfig(Flow f, int parallelismIndex) {
+    private void setFlowConfig(Flow f) {
 
         if (f instanceof PhysicalExecutionFlow) {
             PhysicalExecutionFlow<?, FlowConfig> flow = (PhysicalExecutionFlow<?, FlowConfig>) f;
@@ -702,7 +697,7 @@ public class PhysicalPlanGenerator {
         }
 
         if (!f.getNext().isEmpty()) {
-            f.getNext().forEach(n -> setFlowConfig(n, parallelismIndex));
+            f.getNext().forEach(this::setFlowConfig);
         }
     }
 
