@@ -50,8 +50,8 @@ public class RestConstant {
     @Deprecated public static final String RUNNING_JOB_URL = "/hazelcast/rest/maps/running-job";
     public static final String JOB_INFO_URL = "/hazelcast/rest/maps/job-info";
     public static final String FINISHED_JOBS_INFO = "/hazelcast/rest/maps/finished-jobs";
-    public static final String SUBMIT_JOB_URL = "/hazelcast/rest/maps/submit-job";
     public static final String ENCRYPT_CONFIG = "/hazelcast/rest/maps/encrypt-config";
+    public static final String THREAD_DUMP = "/hazelcast/rest/maps/thread-dump";
 
     // only for test use
     public static final String RUNNING_THREADS = "/hazelcast/rest/maps/running-threads";
@@ -59,5 +59,13 @@ public class RestConstant {
     public static final String SYSTEM_MONITORING_INFORMATION =
             "/hazelcast/rest/maps/system-monitoring-information";
 
+    public static final String SUBMIT_JOB_URL = "/hazelcast/rest/maps/submit-job";
+    public static final String SUBMIT_JOBS_URL = "/hazelcast/rest/maps/submit-jobs";
     public static final String STOP_JOB_URL = "/hazelcast/rest/maps/stop-job";
+    public static final String STOP_JOBS_URL = "/hazelcast/rest/maps/stop-jobs";
+    public static final String UPDATE_TAGS_URL = "/hazelcast/rest/maps/update-tags";
+
+    // metrics
+    public static final String TELEMETRY_METRICS_URL = "/hazelcast/rest/instance/metrics";
+    public static final String TELEMETRY_OPEN_METRICS_URL = "/hazelcast/rest/instance/openmetrics";
 }
