@@ -17,32 +17,47 @@
 
 package org.apache.seatunnel.engine.server;
 
+import org.apache.seatunnel.engine.common.utils.PassiveCompletableFuture;
 import org.apache.seatunnel.engine.server.execution.BlockTask;
 import org.apache.seatunnel.engine.server.execution.ExceptionTestTask;
 import org.apache.seatunnel.engine.server.execution.FixedCallTestTimeTask;
 import org.apache.seatunnel.engine.server.execution.StopTimeTestTask;
 import org.apache.seatunnel.engine.server.execution.Task;
+import org.apache.seatunnel.engine.server.execution.TaskDeployState;
 import org.apache.seatunnel.engine.server.execution.TaskExecutionState;
+import org.apache.seatunnel.engine.server.execution.TaskGroup;
+import org.apache.seatunnel.engine.server.execution.TaskGroupContext;
 import org.apache.seatunnel.engine.server.execution.TaskGroupDefaultImpl;
 import org.apache.seatunnel.engine.server.execution.TaskGroupLocation;
+import org.apache.seatunnel.engine.server.execution.TaskGroupType;
 import org.apache.seatunnel.engine.server.execution.TestTask;
+import org.apache.seatunnel.engine.server.task.TaskGroupImmutableInformation;
 
+import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.RepeatedTest;
 import org.junit.jupiter.api.Test;
 
 import com.google.common.collect.Lists;
 import com.hazelcast.flakeidgen.FlakeIdGenerator;
+import com.hazelcast.internal.serialization.Data;
+import lombok.NonNull;
 
 import java.io.IOException;
+import java.net.MalformedURLException;
+import java.net.URL;
+import java.net.URLClassLoader;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collections;
 import java.util.List;
 import java.util.concurrent.CompletableFuture;
+import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.CopyOnWriteArrayList;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicBoolean;
 
+import static java.util.Collections.emptySet;
 import static org.apache.seatunnel.engine.server.execution.ExecutionState.CANCELED;
 import static org.apache.seatunnel.engine.server.execution.ExecutionState.FAILED;
 import static org.apache.seatunnel.engine.server.execution.ExecutionState.FINISHED;
@@ -63,6 +78,15 @@ public class TaskExecutionServiceTest extends AbstractSeaTunnelServerTest {
         FLAKE_ID_GENERATOR = instance.getFlakeIdGenerator("test");
     }
 
+    private PassiveCompletableFuture<TaskExecutionState> deployLocalTask(
+            TaskExecutionService taskExecutionService, @NonNull TaskGroup taskGroup) {
+        Long taskId = taskGroup.getTasks().iterator().next().getTaskID();
+        ConcurrentHashMap<Long, ClassLoader> classLoaders = new ConcurrentHashMap<>();
+        classLoaders.put(taskId, Thread.currentThread().getContextClassLoader());
+        return taskExecutionService.deployLocalTask(
+                taskGroup, classLoaders, new ConcurrentHashMap<>());
+    }
+
     @Test
     public void testCancel() {
         TaskExecutionService taskExecutionService = server.getTaskExecutionService();
@@ -70,8 +94,8 @@ public class TaskExecutionServiceTest extends AbstractSeaTunnelServerTest {
         long sleepTime = 300;
 
         AtomicBoolean stop = new AtomicBoolean(false);
-        TestTask testTask1 = new TestTask(stop, LOGGER, sleepTime, true);
-        TestTask testTask2 = new TestTask(stop, LOGGER, sleepTime, false);
+        TestTask testTask1 = new TestTask(stop, sleepTime, true);
+        TestTask testTask2 = new TestTask(stop, sleepTime, false);
 
         TaskGroupDefaultImpl ts =
                 new TaskGroupDefaultImpl(
@@ -79,7 +103,7 @@ public class TaskExecutionServiceTest extends AbstractSeaTunnelServerTest {
                         "ts",
                         Lists.newArrayList(testTask1, testTask2));
         CompletableFuture<TaskExecutionState> completableFuture =
-                taskExecutionService.deployLocalTask(ts);
+                deployLocalTask(taskExecutionService, ts);
 
         taskExecutionService.cancelTaskGroup(ts.getTaskGroupLocation());
 
@@ -101,7 +125,7 @@ public class TaskExecutionServiceTest extends AbstractSeaTunnelServerTest {
                         "ts",
                         Lists.newArrayList(testTask1, testTask2));
         CompletableFuture<TaskExecutionState> completableFuture =
-                taskExecutionService.deployLocalTask(ts);
+                deployLocalTask(taskExecutionService, ts);
 
         Thread.sleep(5000);
 
@@ -120,11 +144,12 @@ public class TaskExecutionServiceTest extends AbstractSeaTunnelServerTest {
 
         AtomicBoolean stop = new AtomicBoolean(false);
         AtomicBoolean futureMark = new AtomicBoolean(false);
-        TestTask testTask1 = new TestTask(stop, LOGGER, sleepTime, true);
-        TestTask testTask2 = new TestTask(stop, LOGGER, sleepTime, false);
+        TestTask testTask1 = new TestTask(stop, sleepTime, true);
+        TestTask testTask2 = new TestTask(stop, sleepTime, false);
 
         final CompletableFuture<TaskExecutionState> completableFuture =
-                taskExecutionService.deployLocalTask(
+                deployLocalTask(
+                        taskExecutionService,
                         new TaskGroupDefaultImpl(
                                 new TaskGroupLocation(
                                         jobId, pipeLineId, FLAKE_ID_GENERATOR.newId()),
@@ -141,6 +166,63 @@ public class TaskExecutionServiceTest extends AbstractSeaTunnelServerTest {
         assertTrue(futureMark.get());
     }
 
+    @Test
+    public void testClassloaderSplit() throws MalformedURLException {
+        TaskExecutionService taskExecutionService = server.getTaskExecutionService();
+
+        long sleepTime = 300;
+
+        AtomicBoolean stop = new AtomicBoolean(false);
+        TestTask testTask1 = new TestTask(stop, sleepTime, true);
+        TestTask testTask2 = new TestTask(stop, sleepTime, false);
+
+        long jobId = System.currentTimeMillis();
+
+        TaskGroupLocation location = new TaskGroupLocation(jobId, 1, 1);
+        TaskGroupImmutableInformation taskGroupImmutableInformation =
+                new TaskGroupImmutableInformation(
+                        jobId,
+                        1,
+                        TaskGroupType.INTERMEDIATE_BLOCKING_QUEUE,
+                        location,
+                        "testClassloaderSplit",
+                        Arrays.asList(
+                                nodeEngine.getSerializationService().toData(testTask1),
+                                nodeEngine.getSerializationService().toData(testTask2)),
+                        Arrays.asList(
+                                Collections.singleton(new URL("file://fake.jar")),
+                                Collections.singleton(new URL("file://console.jar"))),
+                        Arrays.asList(emptySet(), emptySet()));
+
+        Data data = nodeEngine.getSerializationService().toData(taskGroupImmutableInformation);
+
+        final TaskDeployState taskDeployState = taskExecutionService.deployTask(data);
+
+        Assertions.assertEquals(TaskDeployState.success(), taskDeployState);
+
+        TaskGroupContext taskGroupContext =
+                taskExecutionService.getActiveExecutionContext(location);
+        Assertions.assertIterableEquals(
+                Collections.singleton(new URL("file://fake.jar")),
+                taskGroupContext.getJars().get(testTask1.getTaskID()));
+        Assertions.assertIterableEquals(
+                Collections.singleton(new URL("file://console.jar")),
+                taskGroupContext.getJars().get(testTask2.getTaskID()));
+
+        Assertions.assertIterableEquals(
+                Collections.singletonList(new URL("file://fake.jar")),
+                Arrays.asList(
+                        ((URLClassLoader) taskGroupContext.getClassLoader(testTask1.getTaskID()))
+                                .getURLs()));
+        Assertions.assertIterableEquals(
+                Collections.singletonList(new URL("file://console.jar")),
+                Arrays.asList(
+                        ((URLClassLoader) taskGroupContext.getClassLoader(testTask2.getTaskID()))
+                                .getURLs()));
+
+        taskExecutionService.cancelTaskGroup(location);
+    }
+
     /** Test task execution time is the same as the timer timeout */
     @Test
     public void testCriticalCallTime() throws InterruptedException {
@@ -158,7 +240,8 @@ public class TaskExecutionServiceTest extends AbstractSeaTunnelServerTest {
         TaskExecutionService taskExecutionService = server.getTaskExecutionService();
 
         CompletableFuture<TaskExecutionState> taskCts =
-                taskExecutionService.deployLocalTask(
+                deployLocalTask(
+                        taskExecutionService,
                         new TaskGroupDefaultImpl(
                                 new TaskGroupLocation(
                                         jobId, pipeLineId, FLAKE_ID_GENERATOR.newId()),
@@ -211,7 +294,8 @@ public class TaskExecutionServiceTest extends AbstractSeaTunnelServerTest {
         Collections.shuffle(tasks);
 
         CompletableFuture<TaskExecutionState> taskCts =
-                taskExecutionService.deployLocalTask(
+                deployLocalTask(
+                        taskExecutionService,
                         new TaskGroupDefaultImpl(
                                 new TaskGroupLocation(
                                         jobId, pipeLineId, FLAKE_ID_GENERATOR.newId()),
@@ -219,7 +303,8 @@ public class TaskExecutionServiceTest extends AbstractSeaTunnelServerTest {
                                 Lists.newArrayList(tasks)));
 
         CompletableFuture<TaskExecutionState> t1c =
-                taskExecutionService.deployLocalTask(
+                deployLocalTask(
+                        taskExecutionService,
                         new TaskGroupDefaultImpl(
                                 new TaskGroupLocation(
                                         jobId, pipeLineId, FLAKE_ID_GENERATOR.newId()),
@@ -227,7 +312,8 @@ public class TaskExecutionServiceTest extends AbstractSeaTunnelServerTest {
                                 Lists.newArrayList(t1)));
 
         CompletableFuture<TaskExecutionState> t2c =
-                taskExecutionService.deployLocalTask(
+                deployLocalTask(
+                        taskExecutionService,
                         new TaskGroupDefaultImpl(
                                 new TaskGroupLocation(
                                         jobId, pipeLineId, FLAKE_ID_GENERATOR.newId()),
@@ -285,7 +371,7 @@ public class TaskExecutionServiceTest extends AbstractSeaTunnelServerTest {
         TaskExecutionService taskExecutionService = server.getTaskExecutionService();
 
         CompletableFuture<TaskExecutionState> completableFuture =
-                taskExecutionService.deployLocalTask(taskGroup);
+                deployLocalTask(taskExecutionService, taskGroup);
 
         // stop tasks
         Thread.sleep(taskRunTime);
