@@ -20,11 +20,8 @@ package org.apache.seatunnel.engine.server.checkpoint;
 import org.apache.seatunnel.common.utils.FileUtils;
 import org.apache.seatunnel.engine.common.exception.SavePointFailedException;
 import org.apache.seatunnel.engine.common.utils.PassiveCompletableFuture;
-import org.apache.seatunnel.engine.core.dag.logical.LogicalDag;
-import org.apache.seatunnel.engine.core.job.JobImmutableInformation;
 import org.apache.seatunnel.engine.core.job.JobStatus;
 import org.apache.seatunnel.engine.server.AbstractSeaTunnelServerTest;
-import org.apache.seatunnel.engine.server.TestUtils;
 
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Disabled;
@@ -32,9 +29,6 @@ import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.condition.DisabledOnOs;
 import org.junit.jupiter.api.condition.OS;
 
-import com.hazelcast.internal.serialization.Data;
-
-import java.util.Collections;
 import java.util.concurrent.CompletionException;
 import java.util.concurrent.TimeUnit;
 
@@ -88,8 +82,7 @@ public class SavePointTest extends AbstractSeaTunnelServerTest<SavePointTest> {
         } catch (Exception e) {
             errorCount++;
         }
-        // we should make sure only one savepoint success in the same time
-        Assertions.assertEquals(2, errorCount);
+        Assertions.assertEquals(3, errorCount);
         await().atMost(120, TimeUnit.SECONDS)
                 .untilAsserted(
                         () ->
@@ -221,24 +214,4 @@ public class SavePointTest extends AbstractSeaTunnelServerTest<SavePointTest> {
 
         Thread.sleep(1000);
     }
-
-    private void startJob(Long jobId, String path, boolean isStartWithSavePoint) {
-        LogicalDag testLogicalDag = TestUtils.createTestLogicalPlan(path, jobId.toString(), jobId);
-
-        JobImmutableInformation jobImmutableInformation =
-                new JobImmutableInformation(
-                        jobId,
-                        "Test",
-                        isStartWithSavePoint,
-                        nodeEngine.getSerializationService().toData(testLogicalDag),
-                        testLogicalDag.getJobConfig(),
-                        Collections.emptyList(),
-                        Collections.emptyList());
-
-        Data data = nodeEngine.getSerializationService().toData(jobImmutableInformation);
-
-        PassiveCompletableFuture<Void> voidPassiveCompletableFuture =
-                server.getCoordinatorService().submitJob(jobId, data);
-        voidPassiveCompletableFuture.join();
-    }
 }
