@@ -21,6 +21,8 @@ import org.apache.seatunnel.shade.com.fasterxml.jackson.databind.JsonNode;
 
 import org.apache.seatunnel.api.serialization.DeserializationSchema;
 import org.apache.seatunnel.api.source.Collector;
+import org.apache.seatunnel.api.table.catalog.CatalogTable;
+import org.apache.seatunnel.api.table.catalog.TablePath;
 import org.apache.seatunnel.api.table.type.RowKind;
 import org.apache.seatunnel.api.table.type.SeaTunnelDataType;
 import org.apache.seatunnel.api.table.type.SeaTunnelRow;
@@ -29,6 +31,7 @@ import org.apache.seatunnel.common.exception.CommonError;
 import org.apache.seatunnel.format.json.JsonDeserializationSchema;
 
 import java.io.IOException;
+import java.util.Optional;
 
 import static java.lang.String.format;
 
@@ -57,23 +60,28 @@ public class DebeziumJsonDeserializationSchema implements DeserializationSchema<
 
     private final boolean debeziumEnabledSchema;
 
-    public DebeziumJsonDeserializationSchema(SeaTunnelRowType rowType, boolean ignoreParseErrors) {
-        this.rowType = rowType;
+    private CatalogTable catalogTable;
+
+    public DebeziumJsonDeserializationSchema(CatalogTable catalogTable, boolean ignoreParseErrors) {
+        this.catalogTable = catalogTable;
+        this.rowType = catalogTable.getSeaTunnelRowType();
         this.ignoreParseErrors = ignoreParseErrors;
         this.jsonDeserializer =
-                new JsonDeserializationSchema(false, ignoreParseErrors, createJsonRowType(rowType));
+                new JsonDeserializationSchema(catalogTable, false, ignoreParseErrors);
         this.debeziumRowConverter = new DebeziumRowConverter(rowType);
         this.debeziumEnabledSchema = false;
     }
 
     public DebeziumJsonDeserializationSchema(
-            SeaTunnelRowType rowType, boolean ignoreParseErrors, boolean debeziumEnabledSchema) {
-        this.rowType = rowType;
+            CatalogTable catalogTable, boolean ignoreParseErrors, boolean debeziumEnabledSchema) {
+        this.catalogTable = catalogTable;
+        this.rowType = catalogTable.getSeaTunnelRowType();
         this.ignoreParseErrors = ignoreParseErrors;
         this.jsonDeserializer =
-                new JsonDeserializationSchema(false, ignoreParseErrors, createJsonRowType(rowType));
+                new JsonDeserializationSchema(catalogTable, false, ignoreParseErrors);
         this.debeziumRowConverter = new DebeziumRowConverter(rowType);
         this.debeziumEnabledSchema = debeziumEnabledSchema;
+        this.catalogTable = catalogTable;
     }
 
     @Override
@@ -83,7 +91,14 @@ public class DebeziumJsonDeserializationSchema implements DeserializationSchema<
     }
 
     @Override
-    public void deserialize(byte[] message, Collector<SeaTunnelRow> out) throws IOException {
+    public void deserialize(byte[] message, Collector<SeaTunnelRow> out) {
+        TablePath tablePath =
+                Optional.ofNullable(catalogTable).map(CatalogTable::getTablePath).orElse(null);
+        deserializeMessage(message, out, tablePath);
+    }
+
+    private void deserializeMessage(
+            byte[] message, Collector<SeaTunnelRow> out, TablePath tablePath) {
         if (message == null || message.length == 0) {
             // skip tombstone messages
             return;
@@ -93,32 +108,50 @@ public class DebeziumJsonDeserializationSchema implements DeserializationSchema<
             JsonNode payload = getPayload(convertBytes(message));
             String op = payload.get("op").asText();
 
-            if (OP_CREATE.equals(op) || OP_READ.equals(op)) {
-                SeaTunnelRow insert = convertJsonNode(payload.get("after"));
-                insert.setRowKind(RowKind.INSERT);
-                out.collect(insert);
-            } else if (OP_UPDATE.equals(op)) {
-                SeaTunnelRow before = convertJsonNode(payload.get("before"));
-                if (before == null) {
-                    throw new IllegalStateException(
-                            String.format(REPLICA_IDENTITY_EXCEPTION, "UPDATE"));
-                }
-                before.setRowKind(RowKind.UPDATE_BEFORE);
-                out.collect(before);
+            switch (op) {
+                case OP_CREATE:
+                case OP_READ:
+                    SeaTunnelRow insert = convertJsonNode(payload.get("after"));
+                    insert.setRowKind(RowKind.INSERT);
+                    if (tablePath != null) {
+                        insert.setTableId(tablePath.toString());
+                    }
+                    out.collect(insert);
+                    break;
+                case OP_UPDATE:
+                    SeaTunnelRow before = convertJsonNode(payload.get("before"));
+                    if (before == null) {
+                        throw new IllegalStateException(
+                                String.format(REPLICA_IDENTITY_EXCEPTION, "UPDATE"));
+                    }
+                    before.setRowKind(RowKind.UPDATE_BEFORE);
+                    if (tablePath != null) {
+                        before.setTableId(tablePath.toString());
+                    }
+                    out.collect(before);
 
-                SeaTunnelRow after = convertJsonNode(payload.get("after"));
-                after.setRowKind(RowKind.UPDATE_AFTER);
-                out.collect(after);
-            } else if (OP_DELETE.equals(op)) {
-                SeaTunnelRow delete = convertJsonNode(payload.get("before"));
-                if (delete == null) {
-                    throw new IllegalStateException(
-                            String.format(REPLICA_IDENTITY_EXCEPTION, "UPDATE"));
-                }
-                delete.setRowKind(RowKind.DELETE);
-                out.collect(delete);
-            } else {
-                throw new IllegalStateException(format("Unknown operation type '%s'.", op));
+                    SeaTunnelRow after = convertJsonNode(payload.get("after"));
+                    after.setRowKind(RowKind.UPDATE_AFTER);
+
+                    if (tablePath != null) {
+                        after.setTableId(tablePath.toString());
+                    }
+                    out.collect(after);
+                    break;
+                case OP_DELETE:
+                    SeaTunnelRow delete = convertJsonNode(payload.get("before"));
+                    if (delete == null) {
+                        throw new IllegalStateException(
+                                String.format(REPLICA_IDENTITY_EXCEPTION, "UPDATE"));
+                    }
+                    delete.setRowKind(RowKind.DELETE);
+                    if (tablePath != null) {
+                        delete.setTableId(tablePath.toString());
+                    }
+                    out.collect(delete);
+                    break;
+                default:
+                    throw new IllegalStateException(format("Unknown operation type '%s'.", op));
             }
         } catch (RuntimeException e) {
             // a big try catch to protect the processing.
