@@ -29,8 +29,8 @@ import org.apache.seatunnel.common.utils.JsonUtils;
 import org.apache.seatunnel.format.json.JsonToRowConverters;
 import org.apache.seatunnel.transform.common.MultipleFieldOutputTransform;
 import org.apache.seatunnel.transform.common.SeaTunnelRowAccessor;
+import org.apache.seatunnel.transform.exception.ErrorDataTransformException;
 import org.apache.seatunnel.transform.exception.TransformCommonError;
-import org.apache.seatunnel.transform.exception.TransformException;
 
 import com.jayway.jsonpath.JsonPath;
 import com.jayway.jsonpath.JsonPathException;
@@ -59,7 +59,7 @@ public class JsonPathTransform extends MultipleFieldOutputTransform {
     private int[] srcFieldIndexArr;
 
     public JsonPathTransform(JsonPathTransformConfig config, CatalogTable catalogTable) {
-        super(catalogTable);
+        super(catalogTable, config.getErrorHandleWay());
         this.config = config;
         this.seaTunnelRowType = catalogTable.getSeaTunnelRowType();
         init();
@@ -122,11 +122,12 @@ public class JsonPathTransform extends MultipleFieldOutputTransform {
         Object[] fieldValues = new Object[size];
         for (int i = 0; i < size; i++) {
             int pos = this.srcFieldIndexArr[i];
+            ColumnConfig fieldConfig = configs.get(i);
             fieldValues[i] =
                     doTransform(
                             seaTunnelRowType.getFieldType(pos),
                             inputRow.getField(pos),
-                            configs.get(i),
+                            fieldConfig,
                             converters[i]);
         }
         return fieldValues;
@@ -168,7 +169,21 @@ public class JsonPathTransform extends MultipleFieldOutputTransform {
             JsonNode jsonNode = JsonUtils.toJsonNode(result);
             return converter.convert(jsonNode, null);
         } catch (JsonPathException e) {
-            throw new TransformException(JSON_PATH_COMPILE_ERROR, e.getMessage());
+            if (columnConfig.errorHandleWay() != null
+                    && columnConfig.errorHandleWay().allowSkip()) {
+                log.debug(
+                        "JsonPath transform error, ignore error, config: {}, value: {}",
+                        columnConfig,
+                        jsonString,
+                        e);
+                return null;
+            }
+            throw new ErrorDataTransformException(
+                    columnConfig.errorHandleWay(),
+                    JSON_PATH_COMPILE_ERROR,
+                    String.format(
+                            "JsonPath transform error, config: %s, value: %s, error: %s",
+                            columnConfig, jsonString, e.getMessage()));
         }
     }
 
