@@ -39,10 +39,12 @@ public class FlinkSinkWriterContext implements SinkWriter.Context {
 
     private final InitContext writerContext;
     private final EventListener eventListener;
+    private final int parallelism;
 
-    public FlinkSinkWriterContext(InitContext writerContext) {
+    public FlinkSinkWriterContext(InitContext writerContext, int parallelism) {
         this.writerContext = writerContext;
         this.eventListener = new DefaultEventProcessor(getJobIdForV14(writerContext));
+        this.parallelism = parallelism;
     }
 
     @Override
@@ -50,6 +52,11 @@ public class FlinkSinkWriterContext implements SinkWriter.Context {
         return writerContext.getSubtaskId();
     }
 
+    @Override
+    public int getNumberOfParallelSubtasks() {
+        return parallelism;
+    }
+
     @Override
     public MetricsContext getMetricsContext() {
         try {
